@@ -5,7 +5,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -51,5 +51,5 @@ int main(int argc, char* argv[])
         n_primes_clear(iter);
     }
 
-    return EXIT_SUCCESS;
+    return 0;
 }
