@@ -1,14 +1,15 @@
 /*
     Copyright (C) 2020 Fredrik Johansson
 
-    This file is part of Arb.
+    This file is part of FLINT.
 
-    Arb is free software: you can redistribute it and/or modify it under
+    FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "test_helpers.h"
 #include "acb.h"
 
 #define NUM_TESTS 256
@@ -271,16 +272,9 @@ const double agm_testdata[NUM_TESTS][6] = {
     {2, 2, 2, 2, 2.00000000000000, 2.00000000000000},
 };
 
-int main(void)
+TEST_FUNCTION_START(acb_agm, state)
 {
     slong iter;
-    flint_rand_t state;
-
-    flint_printf("agm....");
-    fflush(stdout);
-
-    flint_randinit(state);
-
 
     /* test particular values against table */
     {
@@ -427,9 +421,6 @@ int main(void)
         acb_clear(t);
     }
 
-    flint_randclear(state);
-    flint_cleanup();
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
-
+#undef NUM_TESTS
