@@ -1,12 +1,12 @@
 /*
     Copyright (C) 2019 D.H.J. Polymath
 
-    This file is part of Arb.
+    This file is part of FLINT.
 
-    Arb is free software: you can redistribute it and/or modify it under
+    FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "acb_dirichlet.h"
@@ -17,8 +17,7 @@ acb_dirichlet_backlund_s_gram(const fmpz_t n)
     slong res = 0;
     if (fmpz_cmp_si(n, -1) < 0)
     {
-        flint_printf("n must be >= -1\n");
-        flint_abort();
+        flint_throw(FLINT_ERROR, "n must be >= -1\n");
     }
     else
     {
