@@ -1,12 +1,12 @@
 /*
     Copyright (C) 2020 D.H.J. Polymath
 
-    This file is part of Arb.
+    This file is part of FLINT.
 
-    Arb is free software: you can redistribute it and/or modify it under
+    FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "acb_dirichlet.h"
@@ -21,8 +21,7 @@ acb_dirichlet_platt_hardy_z_zeros(
     }
     else if (fmpz_sgn(n) < 1)
     {
-        flint_printf("Nonpositive indices of Hardy Z zeros are not supported.\n");
-        flint_abort();
+        flint_throw(FLINT_ERROR, "Nonpositive indices of Hardy Z zeros are not supported.\n");
     }
     else
     {
