@@ -5,20 +5,18 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "test_helpers.h"
+#include "ulong_extras.h"
 #include "nmod_vec.h"
 #include "aprcl.h"
 
-int main(void)
+TEST_FUNCTION_START(aprcl_f_table, state)
 {
     int i, j;
-    FLINT_TEST_INIT(state);
-
-    flint_printf("f_table....");
-    fflush(stdout);
 
     for (i = 0; i < 10 * flint_test_multiplier(); i++)
     {
@@ -52,9 +50,5 @@ int main(void)
         _nmod_vec_clear(table);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
-
