@@ -2,12 +2,12 @@
     Copyright (C) 2013-2014 Fredrik Johansson
     Copyright (C) 2022 Fredrik Johansson
 
-    This file is part of Arb.
+    This file is part of FLINT.
 
-    Arb is free software: you can redistribute it and/or modify it under
+    FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "thread_support.h"
@@ -593,7 +593,7 @@ arb_atan_gauss_primes_vec_bsplit(arb_ptr res, slong n, slong prec)
 
     /* not implemented */
     if (n > 64)
-        flint_abort();
+        flint_throw(FLINT_ERROR, "(%s)\n", __func__);
 
     wp = prec + 64;
 
@@ -736,7 +736,7 @@ void _arb_atan_gauss_p_ensure_cached(slong prec)
                 n = ARB_LOG_TAB2_PREC / FLINT_BITS;
 
                 if (i >= 24)
-                    flint_abort();
+                    flint_throw(FLINT_ERROR, "(%s)\n", __func__);
                 /* exponent of 2*atan(x) */
                 exp = exponents[i] + 1;
 
