@@ -1,12 +1,12 @@
 /*
     Copyright (C) 2023 Fredrik Johansson
 
-    This file is part of Arb.
+    This file is part of FLINT.
 
-    Arb is free software: you can redistribute it and/or modify it under
+    FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "arb.h"
@@ -46,5 +46,8 @@ arb_nint(arb_t res, const arb_t x, slong prec)
             arb_mul_2exp_si(u, u, -1);
             arb_sub_ui(res, res, 1, prec);
         }
+
+        arb_clear(t);
+        arb_clear(u);
     }
 }
