@@ -1,12 +1,12 @@
 /*
     Copyright (C) 2012 Fredrik Johansson
 
-    This file is part of Arb.
+    This file is part of FLINT.
 
-    Arb is free software: you can redistribute it and/or modify it under
+    FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "fmpq.h"
@@ -21,7 +21,7 @@ arb_zeta_ui_bernoulli(arb_t x, ulong n, slong prec)
     slong wp;
 
     if (n % 2)
-        flint_abort();
+        flint_throw(FLINT_ERROR, "(%s)\n", __func__);
 
     wp = prec + FLINT_BIT_COUNT(n) + 2;
 
@@ -47,4 +47,3 @@ arb_zeta_ui_bernoulli(arb_t x, ulong n, slong prec)
     arb_clear(f);
     fmpq_clear(b);
 }
-
