@@ -1,12 +1,12 @@
 /*
     Copyright (C) 2017 Fredrik Johansson
 
-    This file is part of Arb.
+    This file is part of FLINT.
 
-    Arb is free software: you can redistribute it and/or modify it under
+    FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "fmpz.h"
@@ -19,8 +19,7 @@ arb_fmpz_poly_deflate(fmpz_poly_t result, const fmpz_poly_t input, ulong deflati
 
     if (deflation == 0)
     {
-        flint_printf("Exception (fmpz_poly_deflate). Division by zero.\n");
-        flint_abort();
+        flint_throw(FLINT_ERROR, "Exception (fmpz_poly_deflate). Division by zero.\n");
     }
 
     if (input->length <= 1 || deflation == 1)
@@ -36,4 +35,3 @@ arb_fmpz_poly_deflate(fmpz_poly_t result, const fmpz_poly_t input, ulong deflati
 
     result->length = res_length;
 }
-
