@@ -1,12 +1,12 @@
 /*
     Copyright (C) 2014 Fredrik Johansson
 
-    This file is part of Arb.
+    This file is part of FLINT.
 
-    Arb is free software: you can redistribute it and/or modify it under
+    FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "arf.h"
@@ -28,9 +28,8 @@ arf_mul_rnd_any(arf_ptr z, arf_srcptr x, arf_srcptr y,
 
     if (yn > xn)
     {
-        arf_srcptr __t; mp_size_t __u;
-        __t = x; x = y; y = __t;
-        __u = xn; xn = yn; yn = __u;
+        FLINT_SWAP(arf_srcptr, x, y);
+        FLINT_SWAP(mp_size_t, xn, yn);
     }
 
     /* Either operand is a special value. */
@@ -52,25 +51,7 @@ arf_mul_rnd_any(arf_ptr z, arf_srcptr x, arf_srcptr y,
         alloc = zn = xn + yn;
         ARF_MUL_TMP_ALLOC(tmp, alloc)
 
-        if (yn == 1)
-        {
-            tmp[zn - 1] = mpn_mul_1(tmp, xptr, xn, yptr[0]);
-        }
-        else if (yn >= FLINT_MPN_MUL_THRESHOLD)
-        {
-            flint_mpn_mul_large(tmp, xptr, xn, yptr, yn);
-        }
-        else if (xn == yn)
-        {
-            if (xptr == yptr)
-                mpn_sqr(tmp, xptr, xn);
-            else
-                mpn_mul_n(tmp, xptr, yptr, yn);
-        }
-        else
-        {
-            mpn_mul(tmp, xptr, xn, yptr, yn);
-        }
+        FLINT_MPN_MUL_WITH_SPECIAL_CASES(tmp, xptr, xn, yptr, yn);
 
         inexact = _arf_set_round_mpn(z, &fix, tmp, zn, sgnbit, prec, rnd);
         _fmpz_add2_fast(ARF_EXPREF(z), ARF_EXPREF(x), ARF_EXPREF(y), fix);
@@ -79,4 +60,3 @@ arf_mul_rnd_any(arf_ptr z, arf_srcptr x, arf_srcptr y,
         return inexact;
     }
 }
-
