@@ -5,23 +5,20 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "test_helpers.h"
 #include "fmpz_poly.h"
 #include "arith.h"
 
-int main(void)
+TEST_FUNCTION_START(arith_chebyshev_u_polynomial, state)
 {
     fmpz_poly_t T, U;
 
     slong n;
 
-    FLINT_TEST_INIT(state);
-
-    flint_printf("chebyshev_u_polynomial....");
-    fflush(stdout);
 
     fmpz_poly_init(T);
     fmpz_poly_init(U);
@@ -47,7 +44,5 @@ int main(void)
     fmpz_poly_clear(T);
     fmpz_poly_clear(U);
 
-    FLINT_TEST_CLEANUP(state);
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
