@@ -5,24 +5,21 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "test_helpers.h"
 #include "fmpz.h"
 #include "fmpz_vec.h"
 #include "arith.h"
 
-int main(void)
+TEST_FUNCTION_START(arith_euler_number_vec, state)
 {
     fmpz * r;
     fmpz_t s, t;
     slong k, n;
 
-    FLINT_TEST_INIT(state);
-
-    flint_printf("euler_number_vec....");
-    fflush(stdout);
 
     for (n = 2; n <= 3000; n += (n<100) ? 2 : n/3)
     {
@@ -55,7 +52,5 @@ int main(void)
         _fmpz_vec_clear(r, n + 1);
     }
 
-    FLINT_TEST_CLEANUP(state);
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
