@@ -1,12 +1,12 @@
 /*
     Copyright (C) 2021 Fredrik Johansson
 
-    This file is part of Calcium.
+    This file is part of FLINT.
 
-    Calcium is free software: you can redistribute it and/or modify it under
+    FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "ca.h"
@@ -34,8 +34,7 @@ ca_transfer(ca_t res, ca_ctx_t res_ctx, const ca_t src, ca_ctx_t src_ctx)
 
         if (!ca_set_fexpr(res, expr, res_ctx))
         {
-            flint_printf("ca_transfer: failed to recreate from expression!\n");
-            flint_abort();
+            flint_throw(FLINT_ERROR, "ca_transfer: failed to recreate from expression!\n");
         }
 
         fexpr_clear(expr);
