@@ -5,11 +5,11 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
+#include "test_helpers.h"
 #include "d_vec.h"
 #include "ulong_extras.h"
 
@@ -21,14 +21,9 @@
 
 #define D_VEC_NORM_EPS (1e-14)
 
-int
-main(void)
+TEST_FUNCTION_START(d_vec_norm, state)
 {
     int i, result;
-    FLINT_TEST_INIT(state);
-
-    flint_printf("norm....");
-    fflush(stdout);
 
     /* check sum of norms of parts of a vector is equal to the
        norm of the vector */
@@ -49,18 +44,10 @@ main(void)
 
         result = fabs(res1 + res2 - res3) < D_VEC_NORM_EPS;
         if (!result)
-        {
-            flint_printf("FAIL:\n");
-            printf("%g\n", fabs(res1 + res2 - res3));
-            fflush(stdout);
-            flint_abort();
-        }
+            TEST_FUNCTION_FAIL("%g\n", fabs(res1 + res2 - res3));
 
         _d_vec_clear(a);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
