@@ -7,24 +7,17 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
+#include "test_helpers.h"
 #include "d_vec.h"
 #include "ulong_extras.h"
 
-int
-main(void)
+TEST_FUNCTION_START(d_vec_zero, state)
 {
     int i;
-    FLINT_TEST_INIT(state);
-
-    flint_printf("zero....");
-    fflush(stdout);
-
-
 
     /* Check it's zero */
     for (i = 0; i < 1000 * flint_test_multiplier(); i++)
@@ -40,17 +33,10 @@ main(void)
 
         result = (_d_vec_is_zero(a, len));
         if (!result)
-        {
-            flint_printf("FAIL:\n");
-            fflush(stdout);
-            flint_abort();
-        }
+            TEST_FUNCTION_FAIL("");
 
         _d_vec_clear(a);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
