@@ -5,7 +5,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -21,7 +21,7 @@ void fermat_to_mpz(mpz_t m, mp_limb_t * i, mp_size_t limbs)
    hi = i[limbs];
    if (hi < WORD(0))
    {
-      mpn_neg_n(m->_mp_d, m->_mp_d, limbs + 1);
+      mpn_neg(m->_mp_d, m->_mp_d, limbs + 1);
       m->_mp_size = limbs + 1;
       while ((m->_mp_size) && (!m->_mp_d[m->_mp_size - 1]))
          m->_mp_size--;
