@@ -5,16 +5,17 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "thread_pool.h"
 #include "thread_support.h"
 #include "nmod.h"
 #include "nmod_vec.h"
 #include "nmod_poly.h"
-#include "fft_small.h"
 #include "crt_helpers.h"
+#include "fft_small.h"
 
 static void _mod_red(
     double* abuf, ulong atrunc,
@@ -90,7 +91,7 @@ static void _mod_red(
             {
                 vec8n t = vec8n_load_unaligned(a + i + j);
                 vec8d_store_aligned(aI + j, vec8n_convert_limited_vec8d(t));
-            }            
+            }
         }
 
         vec8d n = vec8d_set_d(fft->p);
@@ -1275,7 +1276,7 @@ P2 = A1*B1
 P1 = (A0 + A1)*(B0 + B1)
 P0 = A0*B0
 
-then 
+then
 
 # P = P0 + (P1 - P2 - P0)*x^k + P2*x^2k
 */
@@ -1365,8 +1366,8 @@ void _nmod_poly_mul_mid(
 
     if (an < bn)
     {
-        PTR_SWAP(const ulong, a, b);
-        ULONG_SWAP(an, bn);
+        FLINT_SWAP(const ulong *, a, b);
+        FLINT_SWAP(ulong, an, bn);
     }
 
     if (zl > bn - 1)
@@ -1419,7 +1420,7 @@ void _nmod_poly_mul_mid(
         else if (0)
         {
             /*
-                two pieces 
+                two pieces
                 +----------------+
                 |             |\ |
                 |             | \|
@@ -1432,7 +1433,7 @@ void _nmod_poly_mul_mid(
         else
         {
             /*
-                two pieces 
+                two pieces
                 +----------------+
                 |           \    |
                 |            \   |
@@ -1464,5 +1465,3 @@ void _nmod_poly_mul_mid(
     _nmod_poly_mul_mid_classical(z, zl, zh, a, an, b, bn, mod);
     return;
 }
-
-
