@@ -5,7 +5,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -47,7 +47,7 @@ static void _fmpq_ball_print(const _fmpq_ball_t x)
 }
 #endif
 
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
 
 static int _fmpq_ball_is_ordered(const _fmpq_ball_t x)
 {
@@ -380,7 +380,7 @@ static slong _uiui_hgcd(
 
 fixed:
 
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
 
     /* should be ok */
 
@@ -444,7 +444,7 @@ fix:
     m22 = t2;
     det *= -1;
 
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
     umul_ppmm(t1,t0, a0, q); t1 += a1*q;
     add_ssaaaa(t1,t0, t1,t0, b1,b0);
     b0 = a0;
@@ -577,8 +577,8 @@ its_ok:
 
     _fmpq_cfrac_list_append_ui(s, s_temp, written);
 
-    FLINT_MPZ_PTR_SWAP(xn, yn);
-    FLINT_MPZ_PTR_SWAP(xd, yd);
+    FLINT_SWAP(mpz_ptr, xn, yn);
+    FLINT_SWAP(mpz_ptr, xd, yd);
 
     goto again;
 
@@ -765,10 +765,10 @@ again:
     /* already checked that s will fit new terms */
     _fmpq_cfrac_list_append_ui(s, s_temp, written);
 
-    FLINT_MPZ_PTR_SWAP(xln, yln);
-    FLINT_MPZ_PTR_SWAP(xld, yld);
-    FLINT_MPZ_PTR_SWAP(xrn, yrn);
-    FLINT_MPZ_PTR_SWAP(xrd, yrd);
+    FLINT_SWAP(mpz_ptr, xln, yln);
+    FLINT_SWAP(mpz_ptr, xld, yld);
+    FLINT_SWAP(mpz_ptr, xrn, yrn);
+    FLINT_SWAP(mpz_ptr, xrd, yrd);
 
     goto again;
 
@@ -858,7 +858,7 @@ void _fmpq_hgcd(_fmpq_cfrac_list_t s, _fmpz_mat22_t M, fmpz_t xa, fmpz_t xb)
     flint_bitcnt_t k, km, shift;
     fmpz_t ya, yb;
     _fmpz_mat22_t N;
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
     fmpz_t xa_org, xb_org;
     fmpz_init_set(xa_org, xa);
     fmpz_init_set(xb_org, xb);
@@ -947,7 +947,7 @@ split:
 
 cleanup:
 
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
     FLINT_ASSERT(_hgcd_ok(M, xa, xb));
     fmpz_mul(ya, M->_11, xa);
     fmpz_addmul(ya, M->_12, xb);
@@ -992,7 +992,7 @@ void _fmpq_ball_get_cfrac(_fmpq_cfrac_list_t s, _fmpz_mat22_t M, int needM,
     fmpz_t q, r;
     _fmpq_ball_t y;
     _fmpz_mat22_t N;
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
     _fmpq_ball_t xorg;
     _fmpq_ball_init(xorg);
     xorg->exact = x->exact;
@@ -1236,7 +1236,7 @@ chop:
 
 cleanup:
 
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
     FLINT_ASSERT(!needM || (_fmpq_ball_apply_mat22_inv(y, M, xorg),
                                                        _fmpq_ball_equal(y, x)));
     _fmpq_ball_clear(xorg);
@@ -1253,4 +1253,3 @@ cleanup:
 
     return;
 }
-
