@@ -5,7 +5,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -50,11 +50,9 @@ void fmpq_pow_si(fmpq_t rop, const fmpq_t op, slong e)
 {
     if (e < 0 && fmpz_is_zero(fmpq_numref(op)))
     {
-        flint_printf("Exception (fmpq_pow_si). Division by zero.\n");
-        flint_abort();
+        flint_throw(FLINT_ERROR, "Exception (fmpq_pow_si). Division by zero.\n");
     }
 
     _fmpq_pow_si(fmpq_numref(rop), fmpq_denref(rop),
                  fmpq_numref(op), fmpq_denref(op), e);
 }
-
