@@ -5,25 +5,17 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
-#include "fmpz.h"
-#include "fmpq.h"
+#include "test_helpers.h"
 #include "fmpz_vec.h"
-#include "ulong_extras.h"
+#include "fmpq.h"
 
-int
-main(void)
+TEST_FUNCTION_START(fmpq_set_fmpz_frac, state)
 {
     int i;
-    FLINT_TEST_INIT(state);
-
-
-    flint_printf("set_fmpz_frac....");
-    fflush(stdout);
 
     for (i = 0; i < 10000; i++)
     {
@@ -61,9 +53,5 @@ main(void)
         fmpz_clear(q);
     }
 
-
-
-    FLINT_TEST_CLEANUP(state);
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
