@@ -5,25 +5,17 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
+#include "test_helpers.h"
 #include "fmpq.h"
 #include "fmpq_vec.h"
-#include "ulong_extras.h"
 
-int
-main(void)
+TEST_FUNCTION_START(fmpq_vec_dot, state)
 {
     int i, result;
-    FLINT_TEST_INIT(state);
-
-    flint_printf("dot....");
-    fflush(stdout);
-
-
 
     /* Check commutative law */
     for (i = 0; i < 1000 * flint_test_multiplier(); i++)
@@ -57,8 +49,5 @@ main(void)
 		fmpq_clear(res2);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
