@@ -5,25 +5,18 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
+#include "test_helpers.h"
 #include "gmpcompat.h"
 #include "ulong_extras.h"
 #include "fmpz.h"
 
-int
-main(void)
+TEST_FUNCTION_START(fmpz_fdiv_ui, state)
 {
     int i, result;
-    FLINT_TEST_INIT(state);
-
-    flint_printf("fdiv_ui....");
-    fflush(stdout);
-
-
 
     for (i = 0; i < 10000 * flint_test_multiplier(); i++)
     {
@@ -42,7 +35,7 @@ main(void)
         r1 = fmpz_fdiv_ui(a, x);
         r2 = flint_mpz_fdiv_ui(b, x);
 
-        result = (r1 == r2);
+        result = (r1 == r2) && _fmpz_is_canonical(a);
         if (!result)
         {
             flint_printf("FAIL:\n");
@@ -56,8 +49,5 @@ main(void)
         mpz_clear(b);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
