@@ -6,28 +6,22 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "test_helpers.h"
 #include <math.h>
-#include "flint.h"
 #include "ulong_extras.h"
 #include "fmpz.h"
 
-int
-main(void)
+TEST_FUNCTION_START(fmpz_get_d_2exp, state)
 {
     int i, result;
 
     double output;
     slong exp;
 
-    FLINT_TEST_INIT(state);
-
-    flint_printf("get_d_2exp....");
-    fflush(stdout);
-
     for (i = 0; i < 1000 * flint_test_multiplier(); i++)
     {
         fmpz_t a;
@@ -51,8 +45,5 @@ main(void)
         fmpz_clear(a);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
