@@ -5,25 +5,18 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
+#include "test_helpers.h"
 #include "ulong_extras.h"
 #include "fmpz.h"
 
-int
-main(void)
+TEST_FUNCTION_START(fmpz_get_mpz, state)
 {
     int i, result;
 
-    FLINT_TEST_INIT(state);
-
-
-    flint_printf("get/set_mpz....");
-    fflush(stdout);
-
     for (i = 0; i < 10000 * flint_test_multiplier(); i++)
     {
         fmpz_t a;
@@ -46,7 +39,7 @@ main(void)
         fmpz_set_mpz(a, b);
         fmpz_get_mpz(c, a);
 
-        result = (mpz_cmp(b, c) == 0);
+        result = (mpz_cmp(b, c) == 0) && _fmpz_is_canonical(a);
         if (!result)
         {
             flint_printf("FAIL:\n");
@@ -61,8 +54,5 @@ main(void)
         mpz_clear(c);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
