@@ -5,24 +5,17 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
+#include "test_helpers.h"
 #include "ulong_extras.h"
 #include "fmpz.h"
 
-int
-main(void)
+TEST_FUNCTION_START(fmpz_size, state)
 {
     int i, result;
-    FLINT_TEST_INIT(state);
-
-    flint_printf("size....");
-    fflush(stdout);
-
-
 
     for (i = 0; i < 10000 * flint_test_multiplier(); i++)
     {
@@ -55,8 +48,5 @@ main(void)
         mpz_clear(b);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
