@@ -5,7 +5,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -28,15 +28,16 @@ int
 fmpz_lll_is_reduced_d(const fmpz_mat_t B, const fmpz_lll_t fl)
 {
 #if HAVE_FENV_H
+    d_mat_t A, R, V, Wu, Wd, bound;
+    double * du, * dd;
+    int rounding_direction = fegetround();
+
     if (fl->rt == Z_BASIS)
     {
         /* NOTE: this algorithm should *not* be changed */
         slong i, j, k, m, n;
-        d_mat_t A, Q, R, V, Wu, Wd, bound, bound2, bound3, boundt, mm, rm, mn,
-            rn, absR;
-        double *du, *dd;
+        d_mat_t Q, bound2, bound3, boundt, mm, rm, mn, rn, absR;
         double s, norm = 0, ti, tj;
-        int rounding_direction = fegetround();
 
         if (B->r == 0 || B->r == 1)
             return 1;
@@ -53,11 +54,8 @@ fmpz_lll_is_reduced_d(const fmpz_mat_t B, const fmpz_lll_t fl)
 
         if (fmpz_mat_get_d_mat_transpose(A, B) == -1)
         {
-            d_mat_clear(A);
             d_mat_clear(Q);
-            d_mat_clear(R);
-            d_mat_clear(V);
-            return 0;
+            goto fail_clear_A_R_V;
         }
 
         for (k = 0; k < n; k++)
@@ -141,17 +139,7 @@ fmpz_lll_is_reduced_d(const fmpz_mat_t B, const fmpz_lll_t fl)
             norm = FLINT_MAX(norm, s);
         }
         if (!(norm < 1))
-        {
-            d_mat_clear(A);
-            d_mat_clear(R);
-            d_mat_clear(V);
-            d_mat_clear(Wu);
-            d_mat_clear(Wd);
-            _d_vec_clear(du);
-            _d_vec_clear(dd);
-            fesetround(rounding_direction);
-            return 0;
-        }
+            goto fail_clear_all;
 
         d_mat_init(bound, n, n);
 
@@ -391,12 +379,7 @@ fmpz_lll_is_reduced_d(const fmpz_mat_t B, const fmpz_lll_t fl)
             norm = FLINT_MAX(norm, s);
         }
         if (!(norm < 1))
-        {
-            d_mat_clear(R);
-            d_mat_clear(bound);
-            fesetround(rounding_direction);
-            return 0;
-        }
+            goto fail_clear_R_bound_rounding_direction;
 
         d_mat_init(absR, n, n);
         for (i = 0; i < n; i++)
@@ -427,12 +410,7 @@ fmpz_lll_is_reduced_d(const fmpz_mat_t B, const fmpz_lll_t fl)
             {
                 tj = fabs(d_mat_entry(R, i, j)) + d_mat_entry(bound, i, j);
                 if (!(tj <= ti))
-                {
-                    d_mat_clear(R);
-                    d_mat_clear(bound);
-                    fesetround(rounding_direction);
-                    return 0;
-                }
+                    goto fail_clear_R_bound_rounding_direction;
             }
             ti = d_mat_entry(R, i, i) + d_mat_entry(bound, i, i);
             fesetround(FE_DOWNWARD);
@@ -449,12 +427,7 @@ fmpz_lll_is_reduced_d(const fmpz_mat_t B, const fmpz_lll_t fl)
             fesetround(FE_UPWARD);
             s = sqrt(s) * ti;
             if (!(s <= tj))
-            {
-                d_mat_clear(R);
-                d_mat_clear(bound);
-                fesetround(rounding_direction);
-                return 0;
-            }
+                goto fail_clear_R_bound_rounding_direction;
         }
 
         d_mat_clear(R);
@@ -465,11 +438,8 @@ fmpz_lll_is_reduced_d(const fmpz_mat_t B, const fmpz_lll_t fl)
     {
         /* NOTE: this algorithm should *not* be changed */
         slong i, j, k, m, n;
-        d_mat_t A, R, V, Wu, Wd, bound, bound2, bound3, boundt, mm, rm, mn,
-            rn, absR;
-        double *du, *dd;
+        d_mat_t bound2, bound3, boundt, mm, rm, mn, rn, absR;
         double s, norm = 0, ti, tj;
-        int rounding_direction = fegetround();
 
         if (B->r == 0 || B->r == 1)
             return 1;
@@ -484,12 +454,7 @@ fmpz_lll_is_reduced_d(const fmpz_mat_t B, const fmpz_lll_t fl)
         d_mat_zero(V);
 
         if (fmpz_mat_get_d_mat_transpose(A, B) == -1)
-        {
-            d_mat_clear(A);
-            d_mat_clear(R);
-            d_mat_clear(V);
-            return 0;
-        }
+            goto fail_clear_A_R_V;
 
         for (j = 0; j < n; j++)
         {
@@ -513,10 +478,7 @@ fmpz_lll_is_reduced_d(const fmpz_mat_t B, const fmpz_lll_t fl)
             if (!(d_mat_entry(R, j, j) > 0))
             {
                 /* going to take sqrt and then divide by it */
-                d_mat_clear(A);
-                d_mat_clear(R);
-                d_mat_clear(V);
-                return 0;
+                goto fail_clear_A_R_V;
             }
 
             d_mat_entry(R, j, j) = sqrt(d_mat_entry(R, j, j));
@@ -568,14 +530,16 @@ fmpz_lll_is_reduced_d(const fmpz_mat_t B, const fmpz_lll_t fl)
         }
         if (!(norm < 1))
         {
-            d_mat_clear(A);
-            d_mat_clear(R);
-            d_mat_clear(V);
+fail_clear_all:
             d_mat_clear(Wu);
             d_mat_clear(Wd);
             _d_vec_clear(du);
             _d_vec_clear(dd);
             fesetround(rounding_direction);
+fail_clear_A_R_V:
+            d_mat_clear(A);
+            d_mat_clear(R);
+            d_mat_clear(V);
             return 0;
         }
 
@@ -789,12 +753,7 @@ fmpz_lll_is_reduced_d(const fmpz_mat_t B, const fmpz_lll_t fl)
             norm = FLINT_MAX(norm, s);
         }
         if (!(norm < 1))
-        {
-            d_mat_clear(R);
-            d_mat_clear(bound);
-            fesetround(rounding_direction);
-            return 0;
-        }
+            goto fail_clear_R_bound_rounding_direction;
 
         d_mat_init(absR, n, n);
         for (i = 0; i < n; i++)
@@ -825,12 +784,7 @@ fmpz_lll_is_reduced_d(const fmpz_mat_t B, const fmpz_lll_t fl)
             {
                 tj = fabs(d_mat_entry(R, i, j)) + d_mat_entry(bound, i, j);
                 if (!(tj <= ti))
-                {
-                    d_mat_clear(R);
-                    d_mat_clear(bound);
-                    fesetround(rounding_direction);
-                    return 0;
-                }
+                    goto fail_clear_R_bound_rounding_direction;
             }
             ti = d_mat_entry(R, i, i) + d_mat_entry(bound, i, i);
             fesetround(FE_DOWNWARD);
@@ -848,6 +802,7 @@ fmpz_lll_is_reduced_d(const fmpz_mat_t B, const fmpz_lll_t fl)
             s = sqrt(s) * ti;
             if (!(s <= tj))
             {
+fail_clear_R_bound_rounding_direction:
                 d_mat_clear(R);
                 d_mat_clear(bound);
                 fesetround(rounding_direction);
