@@ -5,7 +5,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -20,14 +20,16 @@ int
 fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
                          flint_bitcnt_t prec)
 {
+    mpfr_mat_t A, R, V, Wu, Wd, bound;
+    mpfr_ptr du, dd;
+    mpfr_t s, norm, ti, tj, tmp;
+    slong n;
+
     if (fl->rt == Z_BASIS)
     {
         /* NOTE: this algorithm should *not* be changed */
-        slong i, j, k, m, n;
-        mpfr_mat_t A, Q, R, V, Wu, Wd, bound, bound2, bound3, boundt, mm, rm,
-            mn, rn, absR;
-        mpfr_ptr du, dd;
-        mpfr_t s, norm, ti, tj, tmp;
+        slong i, j, k, m;
+        mpfr_mat_t Q, bound2, bound3, boundt, mm, rm, mn, rn, absR;
 
         if (B->r == 0 || B->r == 1)
             return 1;
@@ -157,17 +159,7 @@ fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
             mpfr_max(norm, norm, s, MPFR_RNDU);
         }
         if (mpfr_cmp_ui(norm, 1) >= 0)
-        {
-            mpfr_mat_clear(A);
-            mpfr_mat_clear(R);
-            mpfr_mat_clear(V);
-            mpfr_mat_clear(Wu);
-            mpfr_mat_clear(Wd);
-            _mpfr_vec_clear(du, n);
-            _mpfr_vec_clear(dd, n);
-            mpfr_clears(s, norm, ti, tj, tmp, NULL);
-            return 0;
-        }
+            goto fail_clear_all;
 
         mpfr_mat_init(bound, n, n, prec);
 
@@ -432,12 +424,7 @@ fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
             mpfr_max(norm, norm, s, MPFR_RNDU);
         }
         if (mpfr_cmp_ui(norm, 1) >= 0)
-        {
-            mpfr_mat_clear(R);
-            mpfr_mat_clear(bound);
-            mpfr_clears(s, norm, ti, tj, tmp, NULL);
-            return 0;
-        }
+            goto fail_clear_R_bound_bla;
 
         mpfr_mat_init(absR, n, n, prec);
         for (i = 0; i < n; i++)
@@ -474,12 +461,7 @@ fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
                 mpfr_abs(tmp, mpfr_mat_entry(R, i, j), MPFR_RNDU);
                 mpfr_add(tj, tmp, mpfr_mat_entry(bound, i, j), MPFR_RNDU);
                 if (!mpfr_lessequal_p(tj, ti))
-                {
-                    mpfr_mat_clear(R);
-                    mpfr_mat_clear(bound);
-                    mpfr_clears(s, norm, ti, tj, tmp, NULL);
-                    return 0;
-                }
+                    goto fail_clear_R_bound_bla;
             }
             mpfr_add(ti, mpfr_mat_entry(R, i, i), mpfr_mat_entry(bound, i, i),
                      MPFR_RNDU);
@@ -494,12 +476,7 @@ fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
             mpfr_sqrt(tmp, s, MPFR_RNDU);
             mpfr_mul(s, tmp, ti, MPFR_RNDU);
             if (!mpfr_lessequal_p(s, tj))
-            {
-                mpfr_mat_clear(R);
-                mpfr_mat_clear(bound);
-                mpfr_clears(s, norm, ti, tj, tmp, NULL);
-                return 0;
-            }
+                goto fail_clear_R_bound_bla;
         }
 
         mpfr_mat_clear(R);
@@ -508,11 +485,8 @@ fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
     }
     else
     {
-        slong i, j, k, m, n;
-        mpfr_mat_t A, R, V, Wu, Wd, bound, bound2, bound3, boundt, mm, rm,
-            mn, rn, absR;
-        mpfr_ptr du, dd;
-        mpfr_t s, norm, ti, tj, tmp;
+        slong i, j, k, m;
+        mpfr_mat_t bound2, bound3, boundt, mm, rm, mn, rn, absR;
 
         if (B->r == 0 || B->r == 1)
             return 1;
@@ -566,10 +540,7 @@ fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
             if (mpfr_sgn(mpfr_mat_entry(R, j, j)) <= 0)
             {
                 /* going to take sqrt and then divide by it */
-                mpfr_mat_clear(A);
-                mpfr_mat_clear(R);
-                mpfr_mat_clear(V);
-                return 0;
+                goto fail_clear_A_R_V;
             }
 
             mpfr_sqrt(mpfr_mat_entry(R, j, j), mpfr_mat_entry(R, j, j),
@@ -636,14 +607,16 @@ fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
         }
         if (mpfr_cmp_ui(norm, 1) >= 0)
         {
-            mpfr_mat_clear(A);
-            mpfr_mat_clear(R);
-            mpfr_mat_clear(V);
+fail_clear_all:
             mpfr_mat_clear(Wu);
             mpfr_mat_clear(Wd);
             _mpfr_vec_clear(du, n);
             _mpfr_vec_clear(dd, n);
             mpfr_clears(s, norm, ti, tj, tmp, NULL);
+fail_clear_A_R_V:
+            mpfr_mat_clear(A);
+            mpfr_mat_clear(R);
+            mpfr_mat_clear(V);
             return 0;
         }
 
@@ -880,12 +853,7 @@ fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
             mpfr_max(norm, norm, s, MPFR_RNDU);
         }
         if (mpfr_cmp_ui(norm, 1) >= 0)
-        {
-            mpfr_mat_clear(R);
-            mpfr_mat_clear(bound);
-            mpfr_clears(s, norm, ti, tj, tmp, NULL);
-            return 0;
-        }
+            goto fail_clear_R_bound_bla;
 
         mpfr_mat_init(absR, n, n, prec);
         for (i = 0; i < n; i++)
@@ -922,12 +890,7 @@ fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
                 mpfr_abs(tmp, mpfr_mat_entry(R, i, j), MPFR_RNDU);
                 mpfr_add(tj, tmp, mpfr_mat_entry(bound, i, j), MPFR_RNDU);
                 if (!mpfr_lessequal_p(tj, ti))
-                {
-                    mpfr_mat_clear(R);
-                    mpfr_mat_clear(bound);
-                    mpfr_clears(s, norm, ti, tj, tmp, NULL);
-                    return 0;
-                }
+                    goto fail_clear_R_bound_bla;
             }
             mpfr_add(ti, mpfr_mat_entry(R, i, i), mpfr_mat_entry(bound, i, i),
                      MPFR_RNDU);
@@ -943,6 +906,7 @@ fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
             mpfr_mul(s, tmp, ti, MPFR_RNDU);
             if (!mpfr_lessequal_p(s, tj))
             {
+fail_clear_R_bound_bla:
                 mpfr_mat_clear(R);
                 mpfr_mat_clear(bound);
                 mpfr_clears(s, norm, ti, tj, tmp, NULL);
