@@ -5,7 +5,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -16,9 +16,9 @@ void fmpz_mat_gram(fmpz_mat_t B, const fmpz_mat_t A)
 {
 	slong i, j, k;
 
-	if(B->r != A->r || B->c != A->r) {
-		flint_printf("Exception (fmpz_mat_gram). Incompatible dimensions.\n");
-		flint_abort();
+	if (B->r != A->r || B->c != A->r)
+    {
+        flint_throw(FLINT_ERROR, "(fmpz_mat_gram): Incompatible dimensions.\n");
 	}
 
 	if(B == A) {
