@@ -5,22 +5,19 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "test_helpers.h"
 #include "fmpz.h"
 #include "fmpz_mat.h"
 
-int main(void)
+TEST_FUNCTION_START(fmpz_mat_content, state)
 {
 	int i;
 	fmpz_mat_t A,B;
 	fmpz_t scalar, gcd_mat, temp;
-	FLINT_TEST_INIT(state);
-
-	flint_printf("fmpz_mat_content....");
-	fflush(stdout);
 
 	for (i = 0; i < 100 * flint_test_multiplier(); i++)
 	{
@@ -36,7 +33,6 @@ int main(void)
 		fmpz_init(gcd_mat);
 		fmpz_init(temp);
 
-
 		fmpz_mat_randtest(B, state, 100);
 
 		fmpz_mat_content(gcd_mat, B);
@@ -78,9 +74,5 @@ cleanup:
 		fmpz_clear(gcd_mat);
 	}
 
-
-	FLINT_TEST_CLEANUP(state);
-	flint_printf("PASS\n");
-	return 0;
+    TEST_FUNCTION_END(state);
 }
-
