@@ -5,12 +5,14 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "fmpz_mod_mpoly.h"
 #include "gmpcompat.h"
+#include "fmpz_mod.h"
+#include "mpoly.h"
+#include "fmpz_mod_mpoly.h"
 
 static int _fmpz_mod_mpoly_divrem_monagan_pearce1_binomial(
     fmpz_mod_mpoly_t Q,
