@@ -5,13 +5,16 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "gmpcompat.h"
+#include "nmod.h"
+#include "fmpz_mod.h"
+#include "mpoly.h"
 #include "nmod_mpoly.h"
 #include "fmpz_mod_mpoly.h"
-#include "gmpcompat.h"
 
 #ifdef __GNUC__
 # define sqrt __builtin_sqrt
