@@ -5,11 +5,12 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "fmpz_vec.h"
+#include "mpoly.h"
 #include "fmpz_mod_mpoly.h"
 
 void fmpz_mod_mpoly_univar_init(
@@ -602,7 +603,7 @@ static void mpoly_univar_swap_fmpz_mod_mpoly_univar(
         fmpz_mod_mpoly_swap(COEFF(A, i), B->coeffs + i, ctx);
     }
 
-    SLONG_SWAP(A->length, B->length);
+    FLINT_SWAP(slong, A->length, B->length);
 }
 
 int fmpz_mod_mpoly_univar_pseudo_gcd(
@@ -677,4 +678,3 @@ int fmpz_mod_mpoly_univar_discriminant(
 
     return success;
 }
-
