@@ -5,13 +5,15 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "fmpz_vec.h"
-#include "fmpz_mod_mpoly_factor.h"
+#include "fmpz_mod.h"
 #include "n_poly.h"
+#include "mpoly.h"
+#include "fmpz_mod_mpoly_factor.h"
 
 void fmpz_mod_polyu_init(fmpz_mod_polyu_t A)
 {
@@ -710,7 +712,7 @@ static void fmpz_mod_polyu3_add_zip_limit1(
             for (j = Z->length; j > Zi; j--)
             {
                 fmpz_mod_poly_swap(Zcoeffs + j, Zcoeffs + j - 1, ctx);
-                ULONG_SWAP(Zexps[j], Zexps[j - 1]);
+                FLINT_SWAP(ulong, Zexps[j], Zexps[j - 1]);
             }
 
             Z->length++;
@@ -826,7 +828,7 @@ int fmpz_mod_mpoly_hlift_zippel(
     FLINT_ASSERT(r > 1);
     FLINT_ASSERT(bits <= FLINT_BITS);
 
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
     {
         fmpz_mod_mpoly_t T;
         slong j, * check_degs = FLINT_ARRAY_ALLOC(ctx->minfo->nvars, slong);
