@@ -5,14 +5,14 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
 #include "fmpz.h"
+#include "fmpz_vec.h"
+#include "mpoly.h"
 #include "fmpz_mpoly.h"
-#include "hashmap.h"
 
 /* improve locality */
 #define BLOCK 128
@@ -91,13 +91,15 @@ void _fmpz_mpoly_submul_array1_slong2(ulong * poly1,
       {
          for (i = ii; i < FLINT_MIN(ii + BLOCK, len2); i++)
          {
-            c2 = poly1 + 2*((slong) exp2[i]);
+            /* hack: see mul_array */
+            c2 = poly1 + (((slong) exp2[i]) << 1);
 
             if (poly2[i] != 0)
             {
                for (j = jj; j < FLINT_MIN(jj + BLOCK, len3); j++)
                {
-                  c = c2 + 2*((slong) exp3[j]);
+                  /* hack: see mul_array */
+                  c = c2 + (((slong) exp3[j]) << 1);
 
                   smul_ppmm(p[1], p[0], poly2[i], poly3[j]);
                   sub_ddmmss(c[1], c[0], c[1], c[0], p[1], p[0]);
@@ -247,13 +249,13 @@ void _fmpz_mpoly_submul_array1_slong2_1(ulong * poly1,
    ulong p[2]; /* for products of coefficients */
    ulong * c2, * c;
 
-   c2 = poly1 + 2*((slong) exp2);
+   c2 = poly1 + (((slong) exp2) << 1);
 
    if (d != 0)
    {
       for (j = 0; j < len3; j++)
       {
-         c = c2 + 2*((slong) exp3[j]);
+         c = c2 + (((slong) exp3[j]) << 1);
 
          smul_ppmm(p[1], p[0], d, poly3[j]);
          sub_ddmmss(c[1], c[0], c[1], c[0], p[1], p[0]);
