@@ -5,11 +5,10 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
 #include "fmpz.h"
 #include "fmpz_mpoly.h"
 
@@ -35,3 +34,25 @@ fmpz_mpoly_fit_length(fmpz_mpoly_t poly, slong len, const fmpz_mpoly_ctx_t ctx)
         fmpz_mpoly_realloc(poly, len, ctx);
     }
 }
+
+void _fmpz_mpoly_set_length(fmpz_mpoly_t A, slong newlen, const fmpz_mpoly_ctx_t ctx)
+{
+    slong i;
+    for (i = newlen; i < A->length; i++)
+       _fmpz_demote(A->coeffs + i);
+
+    A->length = newlen;
+}
+
+void fmpz_mpoly_truncate(fmpz_mpoly_t A, slong newlen, const fmpz_mpoly_ctx_t ctx)
+{
+    if (A->length > newlen)
+    {
+        slong i;
+
+        for (i = newlen; i < A->length; i++)
+            _fmpz_demote(A->coeffs + i);
+
+        A->length = newlen;
+    }
+}
