@@ -5,12 +5,15 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include <string.h>
+#include "thread_pool.h"
 #include "thread_support.h"
+#include "fmpz.h"
+#include "fmpz_vec.h"
+#include "mpoly.h"
 #include "fmpz_mpoly.h"
 
 slong _fmpz_mpoly_mul_heap_part1(fmpz ** A_coeff, ulong ** A_exp, slong * A_alloc,
@@ -780,7 +783,7 @@ void _fmpz_mpoly_mul_heap_threaded(
 
     /* we should have managed to keep coefficients past length demoted */
     FLINT_ASSERT(Alen <= Aalloc);
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
     for (i = Alen; i < Aalloc; i++)
     {
         FLINT_ASSERT(!COEFF_IS_MPZ(*(Acoeff + i)));
