@@ -5,16 +5,16 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
 #include "fmpz.h"
+#include "fmpz_vec.h"
 #include "fmpz_poly.h"
+#include "mpoly.h"
 #include "fmpz_mpoly.h"
 
-
 void fmpz_mpoly_univar_init(fmpz_mpoly_univar_t A, const fmpz_mpoly_ctx_t ctx)
 {
     A->coeffs = NULL;
@@ -124,6 +124,17 @@ void fmpz_mpoly_univar_set_coeff_ui(
     return;
 }
 
+int fmpz_mpoly_univar_degree_fits_si(const fmpz_mpoly_univar_t A, const fmpz_mpoly_ctx_t ctx)
+{
+    return A->length == 0 || fmpz_fits_si(A->exps + 0);
+}
+
+slong fmpz_mpoly_univar_get_term_exp_si(fmpz_mpoly_univar_t A, slong i, const fmpz_mpoly_ctx_t ctx)
+{
+    FLINT_ASSERT((ulong)i < (ulong)A->length);
+    return fmpz_get_si(A->exps + i);
+}
+
 void fmpz_mpoly_univar_assert_canonical(fmpz_mpoly_univar_t A, const fmpz_mpoly_ctx_t ctx)
 {
     slong i;
@@ -580,7 +591,7 @@ static void mpoly_univar_swap_fmpz_mpoly_univar(
         fmpz_mpoly_swap(COEFF(A, i), B->coeffs + i, ctx);
     }
 
-    SLONG_SWAP(A->length, B->length);
+    FLINT_SWAP(slong, A->length, B->length);
 }
 
 int fmpz_mpoly_univar_pseudo_gcd(
@@ -655,4 +666,3 @@ int fmpz_mpoly_univar_discriminant(
 
     return success;
 }
-
