@@ -8,7 +8,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -18,7 +18,7 @@
 #ifdef FMPZ_POLY_INLINES_C
 #define FMPZ_POLY_INLINE
 #else
-#define FMPZ_POLY_INLINE static __inline__
+#define FMPZ_POLY_INLINE static inline
 #endif
 
 #include "fmpz_types.h"
@@ -711,6 +711,9 @@ void _fmpz_poly_divrem_preinv(fmpz * Q, fmpz * A, slong len1,
 void fmpz_poly_divrem_preinv(fmpz_poly_t Q, fmpz_poly_t R,
             const fmpz_poly_t A, const fmpz_poly_t B, const fmpz_poly_t B_inv);
 
+void _fmpz_poly_divexact(fmpz * Q, const fmpz * A, slong lenA, const fmpz * B, slong lenB);
+void fmpz_poly_divexact(fmpz_poly_t Q, const fmpz_poly_t A, const fmpz_poly_t B);
+
 fmpz ** _fmpz_poly_powers_precompute(const fmpz * B, slong len);
 
 void fmpz_poly_powers_precompute(fmpz_poly_powers_precomp_t pinv,
@@ -987,21 +990,7 @@ void _fmpz_poly_compose_series(fmpz * res, const fmpz * poly1, slong len1,
 void fmpz_poly_compose_series(fmpz_poly_t res,
                     const fmpz_poly_t poly1, const fmpz_poly_t poly2, slong n);
 
-void _fmpz_poly_revert_series_lagrange(fmpz * Qinv, const fmpz * Q, slong Qlen, slong n);
-
-void fmpz_poly_revert_series_lagrange(fmpz_poly_t Qinv, const fmpz_poly_t Q, slong n);
-
-void _fmpz_poly_revert_series_lagrange_fast(fmpz * Qinv, const fmpz * Q, slong Qlen, slong n);
-
-void fmpz_poly_revert_series_lagrange_fast(fmpz_poly_t Qinv,
-    const fmpz_poly_t Q, slong n);
-
-void _fmpz_poly_revert_series_newton(fmpz * Qinv, const fmpz * Q, slong Qlen, slong n);
-
-void fmpz_poly_revert_series_newton(fmpz_poly_t Qinv, const fmpz_poly_t Q, slong n);
-
 void _fmpz_poly_revert_series(fmpz * Qinv, const fmpz * Q, slong Qlen, slong n);
-
 void fmpz_poly_revert_series(fmpz_poly_t Qinv, const fmpz_poly_t Q, slong n);
 
 /*  Square root  *************************************************************/
