@@ -5,25 +5,18 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
+#include "test_helpers.h"
 #include "fmpz_poly.h"
 #include "long_extras.h"
 #include "ulong_extras.h"
 
-int
-main(void)
+TEST_FUNCTION_START(fmpz_poly_get_set_coeff_si, state)
 {
     int i, j, result;
-    FLINT_TEST_INIT(state);
-
-    flint_printf("get/set_coeff_si....");
-    fflush(stdout);
-
-
 
     for (i = 0; i < 100 * flint_test_multiplier(); i++)
     {
@@ -54,8 +47,5 @@ main(void)
         fmpz_poly_clear(a);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
