@@ -5,10 +5,11 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "test_helpers.h"
 #include "fmpz_poly.h"
 
 static const mp_limb_t known_values[] =
@@ -26,17 +27,12 @@ static const mp_limb_t known_values[] =
     UWORD(394942914)
 };
 
-int main(void)
+TEST_FUNCTION_START(fmpz_poly_swinnerton_dyer, state)
 {
     fmpz_poly_t S;
     mp_limb_t r;
     slong n;
 
-    FLINT_TEST_INIT(state);
-
-    flint_printf("swinnerton_dyer....");
-    fflush(stdout);
-
     for (n = 0; n <= 10; n++)
     {
         fmpz_poly_init(S);
@@ -53,8 +49,5 @@ int main(void)
         fmpz_poly_clear(S);
     }
 
-    FLINT_TEST_CLEANUP(state);
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
-
