@@ -5,11 +5,10 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
 #include "fmpz_poly.h"
 #include "fmpz_poly_mat.h"
 
@@ -46,3 +45,10 @@ fmpz_poly_mat_init(fmpz_poly_mat_t A, slong rows, slong cols)
     A->r = rows;
     A->c = cols;
 }
+
+void
+fmpz_poly_mat_init_set(fmpz_poly_mat_t A, const fmpz_poly_mat_t B)
+{
+    fmpz_poly_mat_init(A, B->r, B->c);
+    fmpz_poly_mat_set(A, B);
+}
