@@ -5,7 +5,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -16,12 +16,5 @@
 void
 fmpz_poly_mat_swap(fmpz_poly_mat_t A, fmpz_poly_mat_t B)
 {
-    if (A != B)
-    {
-        fmpz_poly_mat_struct tmp;
-
-        tmp = *A;
-        *A = *B;
-        *B = tmp;
-    }
+    FLINT_SWAP(fmpz_poly_mat_struct, *A, *B);
 }
