@@ -6,25 +6,16 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
-#include "fmpz.h"
+#include "test_helpers.h"
 #include "fmpz_vec.h"
-#include "ulong_extras.h"
 
-int
-main(void)
+TEST_FUNCTION_START(fmpz_vec_zero, state)
 {
     int i, result;
-    FLINT_TEST_INIT(state);
-
-    flint_printf("zero....");
-    fflush(stdout);
-
-
 
     /* Check it's zero */
     for (i = 0; i < 1000 * flint_test_multiplier(); i++)
@@ -49,8 +40,5 @@ main(void)
         _fmpz_vec_clear(a, len);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
