@@ -5,15 +5,18 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "nmod_vec.h"
+#include "fq_nmod.h"
+#include "n_poly.h"
+#include "mpoly.h"
 #include "nmod_mpoly.h"
 #include "fq_nmod_mpoly.h"
 #include "fq_nmod_mpoly_factor.h"
 
-
 int fq_nmod_mpolyu_is_canonical(const fq_nmod_mpolyu_t A,
                                                  const fq_nmod_mpoly_ctx_t ctx)
 {
@@ -165,7 +168,7 @@ void fq_nmod_mpolyu_degrees_si(
     mpoly_unpack_vec_ui((ulong *) degs, pmax, bits, ctx->minfo->nvars, 1);
 
     for (i = 0; i < ctx->minfo->nvars/2; i++)
-        SLONG_SWAP(degs[i], degs[ctx->minfo->nvars - i - 1]);
+        FLINT_SWAP(slong, degs[i], degs[ctx->minfo->nvars - i - 1]);
 
     TMP_END;
 }
