@@ -5,15 +5,16 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "nmod_mpoly.h"
+#include "fq_nmod.h"
+#include "fq_nmod_poly.h"
+#include "n_poly.h"
+#include "mpoly.h"
 #include "fq_nmod_mpoly.h"
 
-
-
 void fq_nmod_mpolyun_init(
     fq_nmod_mpolyun_t A,
     flint_bitcnt_t bits,
@@ -817,4 +818,3 @@ void fq_nmod_mpolyu_cvtfrom_mpolyun(
     }
     A->length = B->length;
 }
-
