@@ -5,12 +5,16 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "test_helpers.h"
 #include "fq_nmod_mpoly.h"
 
+/* Defined in t-gcd_brown.c, t-gcd.c, t-gcd_cofactors.c, t-gcd_hensel.c,
+ * t-gcd_zippel2.c, t-gcd_zippel.c */
+#define gcd_check gcd_check_gcd_cofactors
 void gcd_check(
     fq_nmod_mpoly_t g,
     fq_nmod_mpoly_t abar,
@@ -245,14 +249,9 @@ cleanup:
     fq_nmod_mpoly_clear(w, ctx);
 }
 
-int
-main(void)
+TEST_FUNCTION_START(fq_nmod_mpoly_gcd_cofactors, state)
 {
     slong i, j, k, tmul = 2;
-    FLINT_TEST_INIT(state);
-
-    flint_printf("gcd_cofactors....");
-    fflush(stdout);
 
     /* The gcd should always work when one input is a monomial */
     for (i = 0; i < tmul * flint_test_multiplier(); i++)
@@ -847,8 +846,6 @@ main(void)
         fq_nmod_mpoly_ctx_clear(ctx);
     }
 
-    printf("PASS\n");
-    FLINT_TEST_CLEANUP(state);
-
-    return 0;
+    TEST_FUNCTION_END(state);
 }
+#undef gcd_check
