@@ -5,14 +5,16 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "nmod_mpoly_factor.h"
+#include "ulong_extras.h"
+#include "fq_nmod.h"
+#include "n_poly.h"
+#include "mpoly.h"
 #include "fq_nmod_mpoly_factor.h"
 
-
 static void _sort_and_delete_duplicates(
     fq_nmod_mpoly_t A,
     slong d,
@@ -708,7 +710,7 @@ static void fq_nmod_polyu3_add_zip_limit1(
             for (j = Z->length; j > Zi; j--)
             {
                 n_poly_swap(Zcoeffs + j, Zcoeffs + j - 1);
-                ULONG_SWAP(Zexps[j], Zexps[j - 1]);
+                FLINT_SWAP(ulong, Zexps[j], Zexps[j - 1]);
             }
 
             Z->length++;
@@ -1042,7 +1044,7 @@ int fq_nmod_mpoly_hlift_zippel(
     FLINT_ASSERT(r > 1);
     FLINT_ASSERT(bits <= FLINT_BITS);
 
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
     {
         fq_nmod_mpoly_t T;
         slong j, * check_degs = FLINT_ARRAY_ALLOC(ctx->minfo->nvars, slong);
@@ -1569,7 +1571,7 @@ cleanup:
     fq_nmod_mpoly_clear(m, ctx);
     fq_nmod_mpoly_clear(mpow, ctx);
 
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
     if (success)
     {
         fq_nmod_mpoly_t prod;
