@@ -5,14 +5,17 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "fq_nmod.h"
 #include "nmod_mat.h"
 #include "fmpz_poly_factor.h"
-#include "nmod_mpoly_factor.h"
+#include "fq_nmod_poly.h"
 #include "fq_nmod_poly_factor.h"
+#include "n_poly.h"
+#include "nmod_mpoly_factor.h"
 #include "fq_nmod_mpoly_factor.h"
 
 #define FLINT_TMP_ARRAY_ALLOC(n, T) (T *) TMP_ALLOC(n*sizeof(T))
@@ -136,7 +139,7 @@ static void _hensel_build_tree(
             }
         }
         n_poly_swap(V + j, V + minp);
-        SLONG_SWAP(link[j], link[minp]);
+        FLINT_SWAP(slong, link[j], link[minp]);
 
         minp = j + 1;
         mind = n_poly_degree(V + j + 1);
@@ -149,7 +152,7 @@ static void _hensel_build_tree(
             }
         }
         n_poly_swap(V + j + 1, V + minp);
-        SLONG_SWAP(link[j + 1], link[minp]);
+        FLINT_SWAP(slong, link[j + 1], link[minp]);
 
         n_fq_poly_mul(V + i, V + j, V + j + 1, ctx);
         link[i] = j;
@@ -213,7 +216,7 @@ static void _hensel_lift_fac(
 
     for (i = 0; i < c->length; i++)
     {
-    #ifdef FLINT_WANT_ASSERT
+    #if FLINT_WANT_ASSERT
         {
             slong j, d = fq_nmod_ctx_degree(ctx);
             for (j = 0; j < FLINT_MIN(p0, c->coeffs[i].length); j++)
@@ -246,7 +249,7 @@ static void _hensel_lift_fac(
     n_bpoly_swap(G, t1);
     n_bpoly_swap(H, t2);
 
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
     {
         slong j, d = fq_nmod_ctx_degree(ctx);
         n_fq_bpoly_mul(t1, G, H, ctx);
@@ -317,7 +320,7 @@ static void _hensel_lift_inv(
 
     for (i = 0; i < c->length; i++)
     {
-    #ifdef FLINT_WANT_ASSERT
+    #if FLINT_WANT_ASSERT
         {
             slong j, d = fq_nmod_ctx_degree(ctx);
             for (j = 0; j < p0; j++)
@@ -350,7 +353,7 @@ static void _hensel_lift_inv(
     n_bpoly_swap(t1, B);
     n_bpoly_swap(t2, A);
 
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
     n_fq_bpoly_mul(t1, G, A, ctx);
     n_fq_bpoly_mul(t2, H, B, ctx);
     n_fq_bpoly_add(c, t1, t2, ctx);
@@ -907,7 +910,7 @@ static void n_fq_bpoly_lift_continue(
     for (k = 0; k < r; k++)
         n_fq_bpoly_reverse_gens(Bfinal + k, B + k, ctx);
 
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
     {
         n_fq_bpoly_t t1, t2;
         n_fq_bpoly_init(t1);
