@@ -6,33 +6,29 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #ifdef T
 
+#include "test_helpers.h"
 #include "templates.h"
 
-int
-main(void)
+TEST_TEMPLATE_FUNCTION_START(T, poly_xgcd_euclidean_f, state)
 {
     int i, result;
-    FLINT_TEST_INIT(state);
-
-    flint_printf("xgcd_euclidean_f....");
-    fflush(stdout);
 
     /* Generic case, most likely co-prime arguments ***************************** */
 
     /* Compare with result from GCD and check correctness */
-    for (i = 0; i < 5 * flint_test_multiplier(); i++)
+    for (i = 0; i < 30 * flint_test_multiplier(); i++)
     {
         TEMPLATE(T, ctx_t) ctx;
         TEMPLATE(T, t) f1, f2;
         TEMPLATE(T, poly_t) a, b, d, g, s, t, v, w;
 
-        TEMPLATE(T, ctx_randtest_reducible) (ctx, state);
+        TEMPLATE(T, ctx_init_randtest_reducible)(ctx, state, 3);
 
         TEMPLATE(T, init) (f1, ctx);
         TEMPLATE(T, init) (f2, ctx);
@@ -44,8 +40,8 @@ main(void)
         TEMPLATE(T, poly_init) (t, ctx);
         TEMPLATE(T, poly_init) (v, ctx);
         TEMPLATE(T, poly_init) (w, ctx);
-        TEMPLATE(T, poly_randtest) (a, state, n_randint(state, 100), ctx);
-        TEMPLATE(T, poly_randtest) (b, state, n_randint(state, 100), ctx);
+        TEMPLATE(T, poly_randtest) (a, state, n_randint(state, 30), ctx);
+        TEMPLATE(T, poly_randtest) (b, state, n_randint(state, 30), ctx);
 
         TEMPLATE(T, poly_gcd_euclidean_f) (f1, d, a, b, ctx);
         TEMPLATE(T, poly_xgcd_euclidean_f) (f2, g, s, t, a, b, ctx);
@@ -104,7 +100,7 @@ main(void)
         TEMPLATE(T, t) f1, f2;
         TEMPLATE(T, poly_t) a, b, d, f, g, s, t, v, w;
 
-        TEMPLATE(T, ctx_randtest_reducible) (ctx, state);
+        TEMPLATE(T, ctx_init_randtest_reducible)(ctx, state, 3);
 
         TEMPLATE(T, init) (f1, ctx);
         TEMPLATE(T, init) (f2, ctx);
@@ -185,13 +181,13 @@ main(void)
     }
 
     /* test aliasing of g and a */
-    for (i = 0; i < 5 * flint_test_multiplier(); i++)
+    for (i = 0; i < 10 * flint_test_multiplier(); i++)
     {
         TEMPLATE(T, ctx_t) ctx;
-	TEMPLATE(T, t) f1, f2;
+        TEMPLATE(T, t) f1, f2;
         TEMPLATE(T, poly_t) a, b, g, s, t, v, w;
 
-        TEMPLATE(T, ctx_randtest) (ctx, state);
+        TEMPLATE(T, ctx_init_randtest)(ctx, state, 3);
 
         TEMPLATE(T, poly_init) (a, ctx);
         TEMPLATE(T, poly_init) (b, ctx);
@@ -200,10 +196,10 @@ main(void)
         TEMPLATE(T, poly_init) (t, ctx);
         TEMPLATE(T, poly_init) (v, ctx);
         TEMPLATE(T, poly_init) (w, ctx);
-	TEMPLATE(T, init) (f1, ctx);
-	TEMPLATE(T, init) (f2, ctx);
-        TEMPLATE(T, poly_randtest) (a, state, n_randint(state, 100), ctx);
-        TEMPLATE(T, poly_randtest) (b, state, n_randint(state, 100), ctx);
+        TEMPLATE(T, init) (f1, ctx);
+        TEMPLATE(T, init) (f2, ctx);
+        TEMPLATE(T, poly_randtest) (a, state, n_randint(state, 20), ctx);
+        TEMPLATE(T, poly_randtest) (b, state, n_randint(state, 20), ctx);
 
         TEMPLATE(T, poly_xgcd_euclidean_f) (f1, g, s, t, a, b, ctx);
         TEMPLATE(T, poly_xgcd_euclidean_f) (f2, a, v, w, a, b, ctx);
@@ -240,13 +236,13 @@ main(void)
     }
 
     /* test aliasing of g and b */
-    for (i = 0; i < 5 * flint_test_multiplier(); i++)
+    for (i = 0; i < 10 * flint_test_multiplier(); i++)
     {
         TEMPLATE(T, ctx_t) ctx;
-	TEMPLATE(T, t) f1, f2;
+        TEMPLATE(T, t) f1, f2;
         TEMPLATE(T, poly_t) a, b, g, s, t, v, w;
 
-        TEMPLATE(T, ctx_randtest) (ctx, state);
+        TEMPLATE(T, ctx_init_randtest)(ctx, state, 0);
 
         TEMPLATE(T, poly_init) (a, ctx);
         TEMPLATE(T, poly_init) (b, ctx);
@@ -255,10 +251,10 @@ main(void)
         TEMPLATE(T, poly_init) (t, ctx);
         TEMPLATE(T, poly_init) (v, ctx);
         TEMPLATE(T, poly_init) (w, ctx);
-	TEMPLATE(T, init) (f1, ctx);
-	TEMPLATE(T, init) (f2, ctx);
-        TEMPLATE(T, poly_randtest) (a, state, n_randint(state, 100), ctx);
-        TEMPLATE(T, poly_randtest) (b, state, n_randint(state, 100), ctx);
+        TEMPLATE(T, init) (f1, ctx);
+        TEMPLATE(T, init) (f2, ctx);
+        TEMPLATE(T, poly_randtest) (a, state, n_randint(state, 20), ctx);
+        TEMPLATE(T, poly_randtest) (b, state, n_randint(state, 20), ctx);
 
         TEMPLATE(T, poly_xgcd_euclidean_f) (f1, g, s, t, a, b, ctx);
         TEMPLATE(T, poly_xgcd_euclidean_f) (f2, b, v, w, a, b, ctx);
@@ -295,13 +291,13 @@ main(void)
     }
 
     /* test aliasing of s and a */
-    for (i = 0; i < 5 * flint_test_multiplier(); i++)
+    for (i = 0; i < 10 * flint_test_multiplier(); i++)
     {
         TEMPLATE(T, ctx_t) ctx;
-	TEMPLATE(T, t) f1, f2;
+        TEMPLATE(T, t) f1, f2;
         TEMPLATE(T, poly_t) a, b, d, g, s, t, w;
 
-        TEMPLATE(T, ctx_randtest) (ctx, state);
+        TEMPLATE(T, ctx_init_randtest)(ctx, state, 0);
 
         TEMPLATE(T, poly_init) (a, ctx);
         TEMPLATE(T, poly_init) (b, ctx);
@@ -312,8 +308,8 @@ main(void)
         TEMPLATE(T, poly_init) (w, ctx);
         TEMPLATE(T, init) (f1, ctx);
         TEMPLATE(T, init) (f2, ctx);
-        TEMPLATE(T, poly_randtest) (a, state, n_randint(state, 100), ctx);
-        TEMPLATE(T, poly_randtest) (b, state, n_randint(state, 100), ctx);
+        TEMPLATE(T, poly_randtest) (a, state, n_randint(state, 20), ctx);
+        TEMPLATE(T, poly_randtest) (b, state, n_randint(state, 20), ctx);
 
         TEMPLATE(T, poly_xgcd_euclidean_f) (f1, g, s, t, a, b, ctx);
         TEMPLATE(T, poly_xgcd_euclidean_f) (f2, d, a, w, a, b, ctx);
@@ -350,13 +346,13 @@ main(void)
     }
 
     /* test aliasing of s and b */
-    for (i = 0; i < 5 * flint_test_multiplier(); i++)
+    for (i = 0; i < 10 * flint_test_multiplier(); i++)
     {
         TEMPLATE(T, ctx_t) ctx;
-	TEMPLATE(T, t) f1, f2;
+        TEMPLATE(T, t) f1, f2;
         TEMPLATE(T, poly_t) a, b, d, g, s, t, w;
 
-        TEMPLATE(T, ctx_randtest) (ctx, state);
+        TEMPLATE(T, ctx_init_randtest)(ctx, state, 3);
 
         TEMPLATE(T, poly_init) (a, ctx);
         TEMPLATE(T, poly_init) (b, ctx);
@@ -367,8 +363,8 @@ main(void)
         TEMPLATE(T, poly_init) (w, ctx);
         TEMPLATE(T, init) (f1, ctx);
         TEMPLATE(T, init) (f2, ctx);
-        TEMPLATE(T, poly_randtest) (a, state, n_randint(state, 100), ctx);
-        TEMPLATE(T, poly_randtest) (b, state, n_randint(state, 100), ctx);
+        TEMPLATE(T, poly_randtest) (a, state, n_randint(state, 20), ctx);
+        TEMPLATE(T, poly_randtest) (b, state, n_randint(state, 20), ctx);
 
         TEMPLATE(T, poly_xgcd_euclidean_f) (f1, g, s, t, a, b, ctx);
         TEMPLATE(T, poly_xgcd_euclidean_f) (f2, d, b, w, a, b, ctx);
@@ -405,13 +401,13 @@ main(void)
     }
 
     /* test aliasing of s and a */
-    for (i = 0; i < 5 * flint_test_multiplier(); i++)
+    for (i = 0; i < 10 * flint_test_multiplier(); i++)
     {
         TEMPLATE(T, ctx_t) ctx;
 	TEMPLATE(T, t) f1, f2;
         TEMPLATE(T, poly_t) a, b, d, g, s, t, w;
 
-        TEMPLATE(T, ctx_randtest) (ctx, state);
+        TEMPLATE(T, ctx_init_randtest)(ctx, state, 0);
 
         TEMPLATE(T, poly_init) (a, ctx);
         TEMPLATE(T, poly_init) (b, ctx);
@@ -422,8 +418,8 @@ main(void)
         TEMPLATE(T, poly_init) (w, ctx);
         TEMPLATE(T, init) (f1, ctx);
         TEMPLATE(T, init) (f2, ctx);
-        TEMPLATE(T, poly_randtest) (a, state, n_randint(state, 100), ctx);
-        TEMPLATE(T, poly_randtest) (b, state, n_randint(state, 100), ctx);
+        TEMPLATE(T, poly_randtest) (a, state, n_randint(state, 20), ctx);
+        TEMPLATE(T, poly_randtest) (b, state, n_randint(state, 20), ctx);
 
         TEMPLATE(T, poly_xgcd_euclidean_f) (f1, g, s, t, a, b, ctx);
         TEMPLATE(T, poly_xgcd_euclidean_f) (f2, d, w, a, a, b, ctx);
@@ -460,13 +456,13 @@ main(void)
     }
 
     /* test aliasing of t and b */
-    for (i = 0; i < 5 * flint_test_multiplier(); i++)
+    for (i = 0; i < 10 * flint_test_multiplier(); i++)
     {
         TEMPLATE(T, ctx_t) ctx;
-	TEMPLATE(T, t) f1, f2;
+        TEMPLATE(T, t) f1, f2;
         TEMPLATE(T, poly_t) a, b, d, g, s, t, w;
 
-        TEMPLATE(T, ctx_randtest) (ctx, state);
+        TEMPLATE(T, ctx_init_randtest)(ctx, state, 0);
 
         TEMPLATE(T, poly_init) (a, ctx);
         TEMPLATE(T, poly_init) (b, ctx);
@@ -477,8 +473,8 @@ main(void)
         TEMPLATE(T, poly_init) (w, ctx);
         TEMPLATE(T, init) (f1, ctx);
         TEMPLATE(T, init) (f2, ctx);
-        TEMPLATE(T, poly_randtest) (a, state, n_randint(state, 100), ctx);
-        TEMPLATE(T, poly_randtest) (b, state, n_randint(state, 100), ctx);
+        TEMPLATE(T, poly_randtest) (a, state, n_randint(state, 20), ctx);
+        TEMPLATE(T, poly_randtest) (b, state, n_randint(state, 20), ctx);
 
         TEMPLATE(T, poly_xgcd_euclidean_f) (f1, g, s, t, a, b, ctx);
         TEMPLATE(T, poly_xgcd_euclidean_f) (f2, d, w, b, a, b, ctx);
@@ -514,10 +510,6 @@ main(void)
         TEMPLATE(T, ctx_clear) (ctx);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
-
 #endif
