@@ -5,7 +5,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -18,8 +18,7 @@ fq_zech_pow(fq_zech_t rop, const fq_zech_t op, const fmpz_t e,
 {
     if (fmpz_sgn(e) < 0)
     {
-        flint_printf("Exception (fq_zech_pow).  e < 0.\n");
-        flint_abort();
+        flint_throw(FLINT_ERROR, "Exception (fq_zech_pow).  e < 0.\n");
     }
     if (fmpz_is_zero(e))
     {
