@@ -5,18 +5,17 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "fq_nmod.h"
 #include "fq_zech.h"
 
 #ifdef T
 #undef T
 #endif
 
-#define T fq_nmod
+#define T fq_zech
 #define CAP_T FQ_ZECH
 #include "fq_templates/test/t-get_set_fmpz.c"
 #undef CAP_T
