@@ -5,8 +5,8 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "fmpz_poly_factor.h"
@@ -16,6 +16,7 @@
 #include "gr.h"
 #include "gr_vec.h"
 #include "gr_poly.h"
+#include "gr_generic.h"
 
 typedef struct
 {
@@ -152,14 +153,25 @@ _gr_arf_set(arf_t res, const arf_t x, const gr_ctx_t ctx)
 }
 
 int
-_gr_arf_set_str(arf_t res, const char * x, const gr_ctx_t ctx)
+_gr_arf_set_str(arf_t res, const char * x, gr_ctx_t ctx)
 {
+    int status;
+
     arb_t t;
     arb_init(t);
-    arb_set_str(t, x, ARF_CTX_PREC(ctx) + 20);
-    arf_set_round(res, arb_midref(t), ARF_CTX_PREC(ctx), ARF_CTX_RND(ctx));
+
+    if (!arb_set_str(t, x, ARF_CTX_PREC(ctx) + 20))
+    {
+        arf_set_round(res, arb_midref(t), ARF_CTX_PREC(ctx), ARF_CTX_RND(ctx));
+        status = GR_SUCCESS;
+    }
+    else
+    {
+        status = gr_generic_set_str_ring_exponents(res, x, ctx);
+    }
+
     arb_clear(t);
-    return GR_SUCCESS;
+    return status;
 }
 
 
