@@ -5,21 +5,21 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include <stdio.h>
+#include <string.h>
+#include "fmpz.h"
+#include "fmpz_mpoly_factor.h"
 #include "gr.h"
 #include "gr_vec.h"
 #include "gr_generic.h"
-#include "fmpz_mpoly.h"
-#include "fmpz_mpoly.h"
-#include "fmpz_mpoly_factor.h"
 
 typedef struct
 {
     fmpz_mpoly_ctx_t mctx;
+    char ** vars;
 }
 _gr_fmpz_mpoly_ctx_t;
 
@@ -44,10 +44,47 @@ int _gr_fmpz_mpoly_ctx_write(gr_stream_t out, gr_ctx_t ctx)
 void
 _gr_fmpz_mpoly_ctx_clear(gr_ctx_t ctx)
 {
+    if (MPOLYNOMIAL_CTX(ctx)->vars != NULL)
+    {
+        slong i;
+        for (i = 0; i < MPOLYNOMIAL_MCTX(ctx)->minfo->nvars; i++)
+            flint_free(MPOLYNOMIAL_CTX(ctx)->vars[i]);
+        flint_free(MPOLYNOMIAL_CTX(ctx)->vars);
+    }
+
     fmpz_mpoly_ctx_clear(MPOLYNOMIAL_MCTX(ctx));
     flint_free(GR_CTX_DATA_AS_PTR(ctx));
 }
 
+int
+_gr_fmpz_mpoly_ctx_set_gen_names(gr_ctx_t ctx, const char ** s)
+{
+    slong i, nvars, len;
+
+    nvars = MPOLYNOMIAL_MCTX(ctx)->minfo->nvars;
+
+    if (MPOLYNOMIAL_CTX(ctx)->vars == NULL)
+    {
+        MPOLYNOMIAL_CTX(ctx)->vars = flint_malloc(nvars * sizeof(char *));
+        for (i = 0; i < nvars; i++)
+            MPOLYNOMIAL_CTX(ctx)->vars[i] = NULL;
+    }
+    else
+    {
+        for (i = 0; i < nvars; i++)
+            flint_free(MPOLYNOMIAL_CTX(ctx)->vars[i]);
+    }
+
+    for (i = 0; i < nvars; i++)
+    {
+        len = strlen(s[i]);
+        MPOLYNOMIAL_CTX(ctx)->vars[i] = flint_realloc(MPOLYNOMIAL_CTX(ctx)->vars[i], len + 1);
+        memcpy(MPOLYNOMIAL_CTX(ctx)->vars[i], s[i], len + 1);
+    }
+
+    return GR_SUCCESS;
+}
+
 void
 _gr_fmpz_mpoly_init(fmpz_mpoly_t res, gr_ctx_t ctx)
 {
@@ -93,17 +130,16 @@ _gr_fmpz_mpoly_randtest_small(fmpz_mpoly_t res, flint_rand_t state, gr_ctx_t ctx
     return GR_SUCCESS;
 }
 
+slong
+_gr_fmpz_mpoly_length(const fmpz_mpoly_t x, gr_ctx_t ctx)
+{
+    return x->length;
+}
+
 int
 _gr_fmpz_mpoly_write(gr_stream_t out, fmpz_mpoly_t poly, gr_ctx_t ctx)
 {
-/*
-    if (out->fp != NULL)
-        fmpz_mpoly_fprint_pretty(out->fp, poly, NULL, MPOLYNOMIAL_MCTX(ctx));
-    else
-*/
-    gr_stream_write_free(out, fmpz_mpoly_get_str_pretty(poly, NULL, MPOLYNOMIAL_MCTX(ctx)));
-
-    /* todo: error handling */
+    gr_stream_write_free(out, fmpz_mpoly_get_str_pretty(poly, (const char **) MPOLYNOMIAL_CTX(ctx)->vars, MPOLYNOMIAL_MCTX(ctx)));
     return GR_SUCCESS;
 }
 
@@ -139,7 +175,7 @@ _gr_fmpz_mpoly_one(fmpz_mpoly_t res, gr_ctx_t ctx)
     return GR_SUCCESS;
 }
 
-truth_t
+int
 _gr_fmpz_mpoly_gens(gr_vec_t res, gr_ctx_t ctx)
 {
     slong i, n;
@@ -507,12 +543,14 @@ gr_method_tab_input _gr_fmpz_mpoly_methods_input[] =
     {GR_METHOD_CTX_IS_FINITE,                   (gr_funcptr) gr_generic_ctx_predicate_false},
     {GR_METHOD_CTX_IS_FINITE_CHARACTERISTIC,    (gr_funcptr) gr_generic_ctx_predicate_false},
     {GR_METHOD_CTX_IS_THREADSAFE,               (gr_funcptr) gr_generic_ctx_predicate_true},
+    {GR_METHOD_CTX_SET_GEN_NAMES,               (gr_funcptr) _gr_fmpz_mpoly_ctx_set_gen_names},
     {GR_METHOD_INIT,        (gr_funcptr) _gr_fmpz_mpoly_init},
     {GR_METHOD_CLEAR,       (gr_funcptr) _gr_fmpz_mpoly_clear},
     {GR_METHOD_SWAP,        (gr_funcptr) _gr_fmpz_mpoly_swap},
     {GR_METHOD_SET_SHALLOW, (gr_funcptr) _gr_fmpz_mpoly_set_shallow},
     {GR_METHOD_RANDTEST,    (gr_funcptr) _gr_fmpz_mpoly_randtest},
     {GR_METHOD_RANDTEST_SMALL,    (gr_funcptr) _gr_fmpz_mpoly_randtest_small},
+    {_GR_METHOD_LENGTH,     (gr_funcptr) _gr_fmpz_mpoly_length},
     {GR_METHOD_WRITE,       (gr_funcptr) _gr_fmpz_mpoly_write},
     {GR_METHOD_ZERO,        (gr_funcptr) _gr_fmpz_mpoly_zero},
     {GR_METHOD_ONE,         (gr_funcptr) _gr_fmpz_mpoly_one},
@@ -526,6 +564,7 @@ gr_method_tab_input _gr_fmpz_mpoly_methods_input[] =
     {GR_METHOD_SET_FMPZ,    (gr_funcptr) _gr_fmpz_mpoly_set_fmpz},
     {GR_METHOD_SET_FMPQ,    (gr_funcptr) _gr_fmpz_mpoly_set_fmpq},
     {GR_METHOD_SET_OTHER,   (gr_funcptr) _gr_fmpz_mpoly_set_other},
+    {GR_METHOD_SET_STR,     (gr_funcptr) gr_generic_set_str_balance_additions},
     {GR_METHOD_NEG,         (gr_funcptr) _gr_fmpz_mpoly_neg},
     {GR_METHOD_ADD,         (gr_funcptr) _gr_fmpz_mpoly_add},
     {GR_METHOD_ADD_SI,      (gr_funcptr) _gr_fmpz_mpoly_add_si},
@@ -564,6 +603,7 @@ gr_ctx_init_fmpz_mpoly(gr_ctx_t ctx, slong nvars, const ordering_t ord)
     ctx->size_limit = WORD_MAX;
 
     fmpz_mpoly_ctx_init(MPOLYNOMIAL_MCTX(ctx), nvars, ord);
+    MPOLYNOMIAL_CTX(ctx)->vars = NULL;
 
     ctx->methods = _gr_fmpz_mpoly_methods;
 
