@@ -5,8 +5,8 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include <stdlib.h>
@@ -19,7 +19,9 @@
 #include "gr.h"
 #include "gr_vec.h"
 #include "gr_poly.h"
+#include "gr_generic.h"
 #include "fmpz_poly_factor.h"
+#include "fmpz_mpoly.h"
 
 #define FMPZ_POLY_CTX(ctx) POLYNOMIAL_CTX(ctx)
 #define FMPZ_POLY_CTX_VAR(ctx) (FMPZ_POLY_CTX(ctx)->var)
@@ -213,16 +215,30 @@ _gr_fmpz_poly_set_other(fmpz_poly_t res, gr_srcptr x, gr_ctx_t x_ctx, const gr_c
     return GR_UNABLE;
 }
 
-/*
 int
 _gr_fmpz_poly_set_str(fmpz_poly_t res, const char * x, const gr_ctx_t ctx)
 {
-    if (fmpz_poly_set_str(res, x))
-        return GR_DOMAIN;
+    fmpz_mpoly_ctx_t fctx;
+    fmpz_mpoly_t f;
+    int status;
+    const char * vars[] = { "x" };
 
-    return GR_SUCCESS;
+    fmpz_mpoly_ctx_init(fctx, 1, ORD_LEX);
+    fmpz_mpoly_init(f, fctx);
+    if (!fmpz_mpoly_set_str_pretty(f, x, vars, fctx))
+    {
+        fmpz_mpoly_get_fmpz_poly(res, f, 0, fctx);
+        status = GR_SUCCESS;
+    }
+    else
+    {
+        status = GR_UNABLE;
+    }
+    fmpz_mpoly_clear(f, fctx);
+    fmpz_mpoly_ctx_clear(fctx);
+
+    return status;
 }
-*/
 
 int
 _gr_fmpz_poly_get_ui(ulong * res, const fmpz_poly_t x, const gr_ctx_t ctx)
@@ -493,7 +509,7 @@ _gr_fmpz_poly_divexact(fmpz_poly_t res, const fmpz_poly_t x, const fmpz_poly_t y
     }
     else
     {
-        fmpz_poly_div(res, x, y);
+        fmpz_poly_divexact(res, x, y);
         return GR_SUCCESS;
     }
 }
@@ -554,6 +570,12 @@ _gr_fmpz_poly_divides(const fmpz_poly_t x, const fmpz_poly_t y, const gr_ctx_t c
     truth_t res;
     fmpz_poly_t tmp;
 
+    if (fmpz_poly_is_zero(y))
+        return T_TRUE;
+
+    if (fmpz_poly_is_zero(x))
+        return T_FALSE;
+
     fmpz_poly_init(tmp);
     res = fmpz_poly_divides(tmp, y, x) ? T_TRUE : T_FALSE;
     fmpz_poly_clear(tmp);
@@ -782,6 +804,7 @@ gr_method_tab_input _fmpz_poly_methods_input[] =
     {GR_METHOD_ZERO,            (gr_funcptr) _gr_fmpz_poly_zero},
     {GR_METHOD_ONE,             (gr_funcptr) _gr_fmpz_poly_one},
     {GR_METHOD_GEN,             (gr_funcptr) _gr_fmpz_poly_gen},
+    {GR_METHOD_GENS,            (gr_funcptr) gr_generic_gens_single},
     {GR_METHOD_IS_ZERO,         (gr_funcptr) _gr_fmpz_poly_is_zero},
     {GR_METHOD_IS_ONE,          (gr_funcptr) _gr_fmpz_poly_is_one},
     {GR_METHOD_IS_NEG_ONE,      (gr_funcptr) _gr_fmpz_poly_is_neg_one},
@@ -791,7 +814,7 @@ gr_method_tab_input _fmpz_poly_methods_input[] =
     {GR_METHOD_SET_UI,          (gr_funcptr) _gr_fmpz_poly_set_ui},
     {GR_METHOD_SET_FMPZ,        (gr_funcptr) _gr_fmpz_poly_set_fmpz},
     {GR_METHOD_SET_OTHER,       (gr_funcptr) _gr_fmpz_poly_set_other},
-/*    {GR_METHOD_SET_STR,         (gr_funcptr) _gr_fmpz_poly_set_str}, */
+    {GR_METHOD_SET_STR,         (gr_funcptr) _gr_fmpz_poly_set_str},
     {GR_METHOD_GET_UI,          (gr_funcptr) _gr_fmpz_poly_get_ui},
     {GR_METHOD_GET_SI,          (gr_funcptr) _gr_fmpz_poly_get_si},
     {GR_METHOD_GET_FMPZ,        (gr_funcptr) _gr_fmpz_poly_get_fmpz},
