@@ -5,8 +5,8 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "nmod_vec.h"
@@ -17,9 +17,11 @@
 #include "fq_nmod_mat.h"
 #include "fq_nmod_poly.h"
 #include "fq_nmod_poly_factor.h"
+#include "fmpz_mod_poly.h"
 #include "gr.h"
 #include "gr_vec.h"
 #include "gr_poly.h"
+#include "gr_generic.h"
 
 #define FQ_CTX(ring_ctx) ((fq_nmod_ctx_struct *)(GR_CTX_DATA_AS_PTR(ring_ctx)))
 
@@ -219,6 +221,33 @@ _gr_fq_nmod_div(fq_nmod_t res, const fq_nmod_t x, const fq_nmod_t y, const gr_ct
     }
 }
 
+int
+_gr_fq_nmod_sqr(fq_nmod_t res, const fq_nmod_t x, const gr_ctx_t ctx)
+{
+    fq_nmod_sqr(res, x, FQ_CTX(ctx));
+    return GR_SUCCESS;
+}
+
+int
+_gr_fq_nmod_pow_ui(fq_nmod_t res, const fq_nmod_t x, ulong y, const gr_ctx_t ctx)
+{
+    fq_nmod_pow_ui(res, x, y, FQ_CTX(ctx));
+    return GR_SUCCESS;
+}
+
+int
+_gr_fq_nmod_pow_fmpz(fq_nmod_t res, const fq_nmod_t x, const fmpz_t y, gr_ctx_t ctx)
+{
+    if (fmpz_sgn(y) < 0)
+    {
+        return gr_generic_pow_fmpz(res, x, y, ctx);
+    }
+    else
+    {
+        fq_nmod_pow(res, x, y, FQ_CTX(ctx));
+        return GR_SUCCESS;
+    }
+}
 
 truth_t
 _gr_fq_nmod_is_invertible(const fq_nmod_t x, const gr_ctx_t ctx)
@@ -246,9 +275,9 @@ _gr_fq_nmod_sqrt(fq_nmod_t res, const fq_nmod_t x, const gr_ctx_t ctx)
 }
 
 int
-_gr_ctx_fq_nmod_prime(fmpz_t p, gr_ctx_t ctx)
+_gr_ctx_fq_nmod_prime(ulong * p, gr_ctx_t ctx)
 {
-    fmpz_set(p, fq_nmod_ctx_prime(FQ_CTX(ctx)));
+    *p = fq_nmod_ctx_prime(FQ_CTX(ctx));
     return GR_SUCCESS;
 }
 
@@ -618,6 +647,7 @@ gr_method_tab_input _fq_nmod_methods_input[] =
     {GR_METHOD_ZERO,            (gr_funcptr) _gr_fq_nmod_zero},
     {GR_METHOD_ONE,             (gr_funcptr) _gr_fq_nmod_one},
     {GR_METHOD_GEN,             (gr_funcptr) _gr_fq_nmod_gen},
+    {GR_METHOD_GENS,            (gr_funcptr) gr_generic_gens_single},
     {GR_METHOD_IS_ZERO,         (gr_funcptr) _gr_fq_nmod_is_zero},
     {GR_METHOD_IS_ONE,          (gr_funcptr) _gr_fq_nmod_is_one},
     {GR_METHOD_EQUAL,           (gr_funcptr) _gr_fq_nmod_equal},
@@ -635,6 +665,10 @@ gr_method_tab_input _fq_nmod_methods_input[] =
     {GR_METHOD_IS_INVERTIBLE,   (gr_funcptr) _gr_fq_nmod_is_invertible},
     {GR_METHOD_INV,             (gr_funcptr) _gr_fq_nmod_inv},
     {GR_METHOD_DIV,             (gr_funcptr) _gr_fq_nmod_div},
+    {GR_METHOD_SQR,             (gr_funcptr) _gr_fq_nmod_sqr},
+    {GR_METHOD_POW_UI,           (gr_funcptr) _gr_fq_nmod_pow_ui},
+    {GR_METHOD_POW_FMPZ,         (gr_funcptr) _gr_fq_nmod_pow_fmpz},
+
     {GR_METHOD_IS_SQUARE,       (gr_funcptr) _gr_fq_nmod_is_square},
     {GR_METHOD_SQRT,            (gr_funcptr) _gr_fq_nmod_sqrt},
 
@@ -675,17 +709,36 @@ _gr_ctx_init_fq_nmod_from_ref(gr_ctx_t ctx, const void * fq_nmod_ctx)
 }
 
 void
-gr_ctx_init_fq_nmod(gr_ctx_t ctx, const fmpz_t p, slong d, const char * var)
+gr_ctx_init_fq_nmod(gr_ctx_t ctx, ulong p, slong d, const char * var)
 {
     fq_nmod_ctx_struct * fq_nmod_ctx;
 
-    if (fmpz_bits(p) > FLINT_BITS)
-    {
-        flint_printf("gr_ctx_init_fq_nmod: expected a word-size p\n");
-        flint_abort();
-    }
-
     fq_nmod_ctx = flint_malloc(sizeof(fq_nmod_ctx_struct));
-    fq_nmod_ctx_init(fq_nmod_ctx, p, d, var == NULL ? "a" : var);
+    fq_nmod_ctx_init_ui(fq_nmod_ctx, p, d, var == NULL ? "a" : var);
     _gr_ctx_init_fq_nmod_from_ref(ctx, fq_nmod_ctx);
 }
+
+int gr_ctx_init_fq_nmod_modulus_nmod_poly(gr_ctx_t ctx, const nmod_poly_t modulus, const char * var)
+{
+    fq_nmod_ctx_struct * fq_nmod_ctx;
+    fq_nmod_ctx = flint_malloc(sizeof(fq_nmod_ctx_struct));
+    fq_nmod_ctx_init_modulus(fq_nmod_ctx, modulus, var == NULL ? "a" : var);
+    _gr_ctx_init_fq_nmod_from_ref(ctx, fq_nmod_ctx);
+    return GR_SUCCESS;
+}
+
+int
+gr_ctx_init_fq_nmod_modulus_fmpz_mod_poly(gr_ctx_t ctx, const fmpz_mod_poly_t modulus, fmpz_mod_ctx_t mod_ctx, const char * var)
+{
+    nmod_poly_t nmodulus;
+    int status;
+
+    if (!fmpz_abs_fits_ui(mod_ctx->n))
+        return GR_UNABLE;
+
+    nmod_poly_init(nmodulus, fmpz_get_ui(mod_ctx->n));
+    fmpz_mod_poly_get_nmod_poly(nmodulus, modulus);
+    status = gr_ctx_init_fq_nmod_modulus_nmod_poly(ctx, nmodulus, var);
+    nmod_poly_clear(nmodulus);
+    return status;
+}
