@@ -5,8 +5,8 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "fmpz_poly.h"
@@ -32,6 +32,13 @@ gr_qqbar_ctx;
 
 #define QQBAR_CTX(ring_ctx) ((gr_qqbar_ctx *)(ring_ctx))
 
+void
+_gr_ctx_qqbar_set_limits(gr_ctx_t ctx, slong deg_limit, slong bits_limit)
+{
+    QQBAR_CTX(ctx)->deg_limit = (deg_limit >= 0) ? deg_limit : WORD_MAX;
+    QQBAR_CTX(ctx)->bits_limit = (bits_limit >= 0) ? bits_limit : WORD_MAX;
+}
+
 int
 _gr_qqbar_ctx_write(gr_stream_t out, gr_ctx_t ctx)
 {
@@ -39,6 +46,19 @@ _gr_qqbar_ctx_write(gr_stream_t out, gr_ctx_t ctx)
         gr_stream_write(out, "Real algebraic numbers (qqbar)");
     else
         gr_stream_write(out, "Complex algebraic numbers (qqbar)");
+
+    if (QQBAR_CTX(ctx)->deg_limit != WORD_MAX)
+    {
+        gr_stream_write(out, ", deg_limit = ");
+        gr_stream_write_si(out, QQBAR_CTX(ctx)->deg_limit);
+    }
+
+    if (QQBAR_CTX(ctx)->bits_limit != WORD_MAX)
+    {
+        gr_stream_write(out, ", bits_limit = ");
+        gr_stream_write_si(out, QQBAR_CTX(ctx)->bits_limit);
+    }
+
     return GR_SUCCESS;
 }
 
@@ -452,6 +472,10 @@ _gr_qqbar_neg(qqbar_t res, const qqbar_t x, const gr_ctx_t ctx)
 int
 _gr_qqbar_add(qqbar_t res, const qqbar_t x, const qqbar_t y, const gr_ctx_t ctx)
 {
+    if (QQBAR_CTX(ctx)->deg_limit != WORD_MAX || QQBAR_CTX(ctx)->bits_limit != WORD_MAX)
+        if (!qqbar_binop_within_limits(x, y, QQBAR_CTX(ctx)->deg_limit, QQBAR_CTX(ctx)->bits_limit))
+            return GR_UNABLE;
+
     qqbar_add(res, x, y);
     return GR_SUCCESS;
 }
@@ -487,6 +511,10 @@ _gr_qqbar_add_fmpq(qqbar_t res, const qqbar_t x, const fmpq_t y, const gr_ctx_t
 int
 _gr_qqbar_sub(qqbar_t res, const qqbar_t x, const qqbar_t y, const gr_ctx_t ctx)
 {
+    if (QQBAR_CTX(ctx)->deg_limit != WORD_MAX || QQBAR_CTX(ctx)->bits_limit != WORD_MAX)
+        if (!qqbar_binop_within_limits(x, y, QQBAR_CTX(ctx)->deg_limit, QQBAR_CTX(ctx)->bits_limit))
+            return GR_UNABLE;
+
     qqbar_sub(res, x, y);
     return GR_SUCCESS;
 }
@@ -522,6 +550,10 @@ _gr_qqbar_sub_fmpq(qqbar_t res, const qqbar_t x, const fmpq_t y, const gr_ctx_t
 int
 _gr_qqbar_mul(qqbar_t res, const qqbar_t x, const qqbar_t y, const gr_ctx_t ctx)
 {
+    if (QQBAR_CTX(ctx)->deg_limit != WORD_MAX || QQBAR_CTX(ctx)->bits_limit != WORD_MAX)
+        if (!qqbar_binop_within_limits(x, y, QQBAR_CTX(ctx)->deg_limit, QQBAR_CTX(ctx)->bits_limit))
+            return GR_UNABLE;
+
     qqbar_mul(res, x, y);
     return GR_SUCCESS;
 }
@@ -577,6 +609,10 @@ _gr_qqbar_div(qqbar_t res, const qqbar_t x, const qqbar_t y, const gr_ctx_t ctx)
     }
     else
     {
+        if (QQBAR_CTX(ctx)->deg_limit != WORD_MAX || QQBAR_CTX(ctx)->bits_limit != WORD_MAX)
+            if (!qqbar_binop_within_limits(x, y, QQBAR_CTX(ctx)->deg_limit, QQBAR_CTX(ctx)->bits_limit))
+                return GR_UNABLE;
+
         qqbar_div(res, x, y);
         return GR_SUCCESS;
     }
@@ -647,6 +683,32 @@ _gr_qqbar_is_invertible(const qqbar_t x, const gr_ctx_t ctx)
 int
 _gr_qqbar_pow_ui(qqbar_t res, const qqbar_t x, ulong exp, const gr_ctx_t ctx)
 {
+    if (QQBAR_CTX(ctx)->bits_limit != WORD_MAX && !(exp == 0 || exp == 1))
+    {
+        slong ebits = FLINT_BIT_COUNT(exp);
+
+        if (qqbar_is_zero(x) || qqbar_is_one(x))
+        {
+            qqbar_set(res, x);
+            return GR_SUCCESS;
+        }
+
+        if (qqbar_is_neg_one(x))
+        {
+            if (exp % 2 == 0)
+                qqbar_one(res);
+            else
+                qqbar_set(res, x);
+            return GR_SUCCESS;
+        }
+
+        if (ebits > SMALL_FMPZ_BITCOUNT_MAX)
+            return GR_UNABLE;
+
+        if ((double) exp * qqbar_height_bits(x) > QQBAR_CTX(ctx)->bits_limit)
+            return GR_UNABLE;
+    }
+
     qqbar_pow_ui(res, x, exp);
     return GR_SUCCESS;
 }
@@ -660,6 +722,32 @@ _gr_qqbar_pow_si(qqbar_t res, const qqbar_t x, slong exp, const gr_ctx_t ctx)
     }
     else
     {
+        if (QQBAR_CTX(ctx)->bits_limit != WORD_MAX && !(exp == 0 || exp == 1 || exp == -1))
+        {
+            slong ebits = FLINT_BIT_COUNT(FLINT_ABS(exp));
+
+            if (qqbar_is_zero(x) || qqbar_is_one(x))
+            {
+                qqbar_set(res, x);
+                return GR_SUCCESS;
+            }
+
+            if (qqbar_is_neg_one(x))
+            {
+                if (exp % 2 == 0)
+                    qqbar_one(res);
+                else
+                    qqbar_set(res, x);
+                return GR_SUCCESS;
+            }
+
+            if (ebits > SMALL_FMPZ_BITCOUNT_MAX)
+                return GR_UNABLE;
+
+            if ((double) FLINT_ABS(exp) * qqbar_height_bits(x) > QQBAR_CTX(ctx)->bits_limit)
+                return GR_UNABLE;
+        }
+
         qqbar_pow_si(res, x, exp);
         return GR_SUCCESS;
     }
@@ -674,6 +762,32 @@ _gr_qqbar_pow_fmpz(qqbar_t res, const qqbar_t x, const fmpz_t exp, const gr_ctx_
     }
     else
     {
+        if (QQBAR_CTX(ctx)->bits_limit != WORD_MAX && !(fmpz_is_zero(exp) || fmpz_is_pm1(exp)))
+        {
+            slong ebits = fmpz_bits(exp);
+
+            if (qqbar_is_zero(x) || qqbar_is_one(x))
+            {
+                qqbar_set(res, x);
+                return GR_SUCCESS;
+            }
+
+            if (qqbar_is_neg_one(x))
+            {
+                if (fmpz_is_even(exp))
+                    qqbar_one(res);
+                else
+                    qqbar_set(res, x);
+                return GR_SUCCESS;
+            }
+
+            if (ebits > SMALL_FMPZ_BITCOUNT_MAX)
+                return GR_UNABLE;
+
+            if ((double) FLINT_ABS(*exp) * qqbar_height_bits(x) > QQBAR_CTX(ctx)->bits_limit)
+                return GR_UNABLE;
+        }
+
         qqbar_pow_fmpz(res, x, exp);
         return GR_SUCCESS;
     }
@@ -1167,6 +1281,7 @@ gr_method_tab_input _qqbar_methods_input[] =
     {GR_METHOD_SET_FMPQ,        (gr_funcptr) _gr_qqbar_set_fmpq},
     {GR_METHOD_SET_D,           (gr_funcptr) _gr_qqbar_set_d},
     {GR_METHOD_SET_OTHER,       (gr_funcptr) _gr_qqbar_set_other},
+    {GR_METHOD_SET_STR,         (gr_funcptr) gr_generic_set_str_ring_exponents},
 
     {GR_METHOD_GET_SI,          (gr_funcptr) _gr_qqbar_get_si},
     {GR_METHOD_GET_UI,          (gr_funcptr) _gr_qqbar_get_ui},
