@@ -1,17 +1,22 @@
-#include "ulong_extras.h"
+/*
+    Copyright (C) 2023 Fredrik Johansson
+
+    This file is part of FLINT.
+
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
+*/
+
+#include "test_helpers.h"
 #include "gr.h"
 
-int main(void)
+TEST_FUNCTION_START(gr_series_arb, state)
 {
     gr_ctx_t RRn, RRnx;
     int flags = 0;
     slong i;
-    flint_rand_t state;
-
-    flint_randinit(state);
-
-    flint_printf("series_arb....");
-    fflush(stdout);
 
     for (i = 0; i < 5; i++)
     {
@@ -33,9 +38,5 @@ int main(void)
 
     gr_ctx_clear(RRn);
 
-    flint_randclear(state);
-
-    flint_cleanup();
-    flint_printf(" PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
