@@ -5,8 +5,8 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "fmpq.h"
@@ -48,6 +48,35 @@ truth_t gr_generic_ctx_predicate_false(gr_ctx_t ctx)
     return T_FALSE;
 }
 
+truth_t gr_generic_ctx_is_zero_ring(gr_ctx_t ctx)
+{
+    gr_ptr t;
+    int status;
+    truth_t res;
+
+    if (gr_ctx_is_integral_domain(ctx) == T_TRUE)
+    {
+        return T_FALSE;
+    }
+    else
+    {
+        GR_TMP_INIT(t, ctx);
+
+        status = gr_one(t, ctx);
+
+        if (status & GR_UNABLE)
+            res = T_UNKNOWN;
+        else if (status & GR_DOMAIN)
+            res = T_FALSE;
+        else
+            res = gr_is_zero(t, ctx);
+    }
+
+    GR_TMP_CLEAR(t, ctx);
+
+    return res;
+}
+
 void
 gr_generic_set_shallow(gr_ptr res, gr_srcptr x, const gr_ctx_t ctx)
 {
@@ -112,6 +141,29 @@ int gr_generic_randtest_small(gr_ptr x, flint_rand_t state, gr_ctx_t ctx)
     return status;
 }
 
+slong _gr_generic_length(gr_srcptr x, gr_ctx_t ctx)
+{
+    return 0;
+}
+
+
+int gr_generic_gens(gr_vec_t vec, gr_ctx_t ctx)
+{
+    gr_vec_set_length(vec, 0, ctx);
+    return GR_SUCCESS;
+}
+
+int gr_generic_gens_single(gr_vec_t vec, gr_ctx_t ctx)
+{
+    gr_vec_set_length(vec, 1, ctx);
+    return gr_gen(vec->entries, ctx);
+}
+
+int gr_generic_gens_recursive(gr_vec_t vec, gr_ctx_t ctx)
+{
+    return gr_gens(vec, ctx);
+}
+
 /* Generic arithmetic functions */
 
 truth_t gr_generic_is_zero(gr_srcptr x, gr_ctx_t ctx)
@@ -810,6 +862,48 @@ int gr_generic_get_fmpz_2exp_fmpz(fmpz_t res1, fmpz_t res2, gr_ptr x, gr_ctx_t c
     return status;
 }
 
+int gr_generic_set_fmpz_10exp_fmpz(gr_ptr res, const fmpz_t x, const fmpz_t y, gr_ctx_t ctx)
+{
+    if (fmpz_is_zero(y))
+    {
+        return gr_set_fmpz(res, x, ctx);
+    }
+    else if (fmpz_is_zero(x))
+    {
+        return gr_zero(res, ctx);
+    }
+    else
+    {
+        gr_ptr t;
+        int status;
+
+        GR_TMP_INIT(t, ctx);
+
+        status = gr_set_ui(t, 10, ctx);
+
+        if (fmpz_sgn(y) > 0)
+        {
+            status |= gr_pow_fmpz(t, t, y, ctx);
+            status |= gr_set_fmpz(res, x, ctx);
+            status |= gr_mul(res, res, t, ctx);
+        }
+        else
+        {
+            fmpz_t e;
+            fmpz_init(e);
+            fmpz_neg(e, y);
+            status |= gr_pow_fmpz(t, t, e, ctx);
+            status |= gr_set_fmpz(res, x, ctx);
+            status |= gr_div(res, res, t, ctx);
+            fmpz_clear(e);
+        }
+
+        GR_TMP_CLEAR(t, ctx);
+
+        return status;
+    }
+}
+
 int gr_generic_get_fexpr_serialize(fexpr_t res, gr_srcptr x, gr_ctx_t ctx)
 {
     return gr_get_fexpr(res, x, ctx);
@@ -847,7 +941,6 @@ truth_t gr_generic_is_invertible(gr_srcptr x, gr_ctx_t ctx)
     return T_UNKNOWN;
 }
 
-
 int gr_generic_div_fmpz(gr_ptr res, gr_srcptr x, const fmpz_t y, gr_ctx_t ctx)
 {
     gr_ptr t;
@@ -954,6 +1047,60 @@ int gr_generic_divexact(gr_ptr res, gr_srcptr x, gr_srcptr y, gr_ctx_t ctx)
     return gr_div(res, x, y, ctx);
 }
 
+truth_t gr_generic_div_nonunique(gr_ptr res, gr_srcptr x, gr_srcptr y, gr_ctx_t ctx)
+{
+    truth_t zero;
+    int status;
+
+    /* 0 = q * y has 0 as a solution, even if y = 0 */
+    zero = gr_is_zero(x, ctx);
+    if (zero == T_TRUE)
+    {
+        status = gr_zero(res, ctx);
+        return (status == GR_SUCCESS) ? T_TRUE : T_UNKNOWN;
+    }
+
+    status = gr_div(res, x, y, ctx);
+
+    if (status == GR_SUCCESS)
+        return T_TRUE;
+
+    /* In an integral domain, div should find the unique quotient
+       or assert that none exists. */
+    if (gr_ctx_is_integral_domain(ctx) == T_TRUE)
+        return status;
+
+    /* The ring would need to implement this case. */
+    return GR_UNABLE;
+}
+
+truth_t gr_generic_divides(gr_srcptr x, gr_srcptr y, gr_ctx_t ctx)
+{
+    gr_ptr t;
+    truth_t zero;
+    int status;
+
+    zero = gr_is_zero(y, ctx);
+    if (zero == T_TRUE)
+        return T_TRUE;
+
+    GR_TMP_INIT(t, ctx);
+    status = gr_div(t, y, x, ctx);
+    GR_TMP_CLEAR(t, ctx);
+
+    if (status == GR_SUCCESS)
+        return T_TRUE;
+
+    if (gr_ctx_is_integral_domain(ctx) != T_TRUE)
+        return T_UNKNOWN;
+
+    if (status == GR_DOMAIN)
+        return T_FALSE;
+
+    return T_UNKNOWN;
+}
+
+
 /* at least catch square roots -- todo: generalize to nth roots */
 int
 gr_generic_pow_fmpq(gr_ptr res, gr_srcptr x, const fmpq_t y, gr_ctx_t ctx)
@@ -2379,6 +2526,7 @@ const gr_method_tab_input _gr_generic_methods[] =
     {GR_METHOD_CTX_IS_FINITE,           (gr_funcptr) gr_generic_ctx_predicate},
     {GR_METHOD_CTX_IS_FINITE_CHARACTERISTIC,        (gr_funcptr) gr_generic_ctx_predicate},
     {GR_METHOD_CTX_IS_ALGEBRAICALLY_CLOSED,         (gr_funcptr) gr_generic_ctx_predicate},
+    {GR_METHOD_CTX_IS_ZERO_RING,        (gr_funcptr) gr_generic_ctx_is_zero_ring},
 
     {GR_METHOD_CTX_IS_ORDERED_RING,     (gr_funcptr) gr_generic_ctx_predicate},
 
@@ -2393,6 +2541,8 @@ const gr_method_tab_input _gr_generic_methods[] =
     {GR_METHOD_SWAP,                    (gr_funcptr) gr_generic_swap},
     {GR_METHOD_SET_SHALLOW,             (gr_funcptr) gr_generic_set_shallow},
 
+    {_GR_METHOD_LENGTH,                 (gr_funcptr) _gr_generic_length},
+
     {GR_METHOD_WRITE,                   (gr_funcptr) gr_generic_write},
     {GR_METHOD_WRITE_N,                 (gr_funcptr) gr_generic_write_n},
 
@@ -2400,6 +2550,9 @@ const gr_method_tab_input _gr_generic_methods[] =
     {GR_METHOD_RANDTEST_NOT_ZERO,       (gr_funcptr) gr_generic_randtest_not_zero},
     {GR_METHOD_RANDTEST_SMALL,          (gr_funcptr) gr_generic_randtest_small},
 
+    {GR_METHOD_GENS,                    (gr_funcptr) gr_generic_gens},
+    {GR_METHOD_GENS_RECURSIVE,          (gr_funcptr) gr_generic_gens_recursive},
+
     {GR_METHOD_ZERO,                    (gr_funcptr) gr_generic_zero},
     {GR_METHOD_ONE,                     (gr_funcptr) gr_generic_one},
     {GR_METHOD_NEG_ONE,                 (gr_funcptr) gr_generic_neg_one},
@@ -2418,6 +2571,8 @@ const gr_method_tab_input _gr_generic_methods[] =
 
     {GR_METHOD_SET_OTHER,               (gr_funcptr) gr_generic_set_other},
 
+    {GR_METHOD_SET_STR,                 (gr_funcptr) gr_generic_set_str},
+
     {GR_METHOD_GET_FEXPR_SERIALIZE,     (gr_funcptr) gr_generic_get_fexpr_serialize},
     {GR_METHOD_SET_FEXPR,               (gr_funcptr) gr_generic_set_fexpr},
 
@@ -2468,6 +2623,7 @@ const gr_method_tab_input _gr_generic_methods[] =
     {GR_METHOD_MUL_2EXP_FMPZ,           (gr_funcptr) gr_generic_mul_2exp_fmpz},
     {GR_METHOD_SET_FMPZ_2EXP_FMPZ,      (gr_funcptr) gr_generic_set_fmpz_2exp_fmpz},
     {GR_METHOD_GET_FMPZ_2EXP_FMPZ,      (gr_funcptr) gr_generic_get_fmpz_2exp_fmpz},
+    {GR_METHOD_SET_FMPZ_10EXP_FMPZ,     (gr_funcptr) gr_generic_set_fmpz_10exp_fmpz},
 
     {GR_METHOD_DIV_UI,                  (gr_funcptr) gr_generic_div_ui},
     {GR_METHOD_DIV_SI,                  (gr_funcptr) gr_generic_div_si},
@@ -2484,6 +2640,9 @@ const gr_method_tab_input _gr_generic_methods[] =
     {GR_METHOD_DIVEXACT_OTHER,          (gr_funcptr) gr_generic_div_other},
     {GR_METHOD_OTHER_DIVEXACT,          (gr_funcptr) gr_generic_other_div},
 
+    {GR_METHOD_DIV_NONUNIQUE,           (gr_funcptr) gr_generic_div_nonunique},
+    {GR_METHOD_DIVIDES,                 (gr_funcptr) gr_generic_divides},
+
     {GR_METHOD_IS_INVERTIBLE,           (gr_funcptr) gr_generic_is_invertible},
     {GR_METHOD_INV,                     (gr_funcptr) gr_generic_inv},
 
@@ -2715,6 +2874,7 @@ const gr_method_tab_input _gr_generic_methods[] =
     {GR_METHOD_POLY_EXP_SERIES,         (gr_funcptr) _gr_poly_exp_series_generic},
 
     {GR_METHOD_MAT_MUL,                 (gr_funcptr) gr_mat_mul_generic},
+    {GR_METHOD_MAT_LU,                  (gr_funcptr) gr_mat_lu_generic},
     {GR_METHOD_MAT_DET,                 (gr_funcptr) gr_mat_det_generic},
     {GR_METHOD_MAT_EXP,                 (gr_funcptr) gr_mat_exp_jordan},
     {GR_METHOD_MAT_LOG,                 (gr_funcptr) gr_mat_log_jordan},
@@ -2728,9 +2888,13 @@ void
 gr_method_tab_init(gr_funcptr * methods, gr_method_tab_input * tab)
 {
     slong i;
+    /* Write to a temporary table so that gr_not_implemented entries
+       do not overwrite proper entries if there are multiple threads
+       trying to init the same table simultaneously. */
+    gr_static_method_table tmp;
 
     for (i = 0; i < GR_METHOD_TAB_SIZE; i++)
-        methods[i] = (gr_funcptr) gr_not_implemented;
+        tmp[i] = (gr_funcptr) gr_not_implemented;
 
     /* Assign generic methods as fallbacks */
     for (i = 0; ; i++)
@@ -2739,9 +2903,9 @@ gr_method_tab_init(gr_funcptr * methods, gr_method_tab_input * tab)
             break;
 
         if (_gr_generic_methods[i].index >= GR_METHOD_TAB_SIZE)
-            flint_abort();
+            flint_throw(FLINT_ERROR, "(%s)\n", __func__);
 
-        methods[_gr_generic_methods[i].index] = _gr_generic_methods[i].function;
+        tmp[_gr_generic_methods[i].index] = _gr_generic_methods[i].function;
     }
 
     for (i = 0; ; i++)
@@ -2750,8 +2914,10 @@ gr_method_tab_init(gr_funcptr * methods, gr_method_tab_input * tab)
             break;
 
         if (tab[i].index >= GR_METHOD_TAB_SIZE)
-            flint_abort();
+            flint_throw(FLINT_ERROR, "(%s)\n", __func__);
 
-        methods[tab[i].index] = tab[i].function;
+        tmp[tab[i].index] = tab[i].function;
     }
+
+    memcpy(methods, tmp, sizeof(gr_static_method_table));
 }
