@@ -5,8 +5,8 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "gr_mat.h"
@@ -17,29 +17,17 @@ gr_mat_invert_cols(gr_mat_t mat, slong * perm, gr_ctx_t ctx)
     if (gr_mat_is_empty(mat, ctx) == T_FALSE)
     {
         slong sz = ctx->sizeof_elem;
-
-        slong t;
-        slong i;
+        slong t, i;
         slong c = mat->c;
         slong k = mat->c / 2;
 
         if (perm != NULL)
-        {
             for (i = 0; i < k; i++)
-            {
-                t = perm[i];
-                perm[i] = perm[c - i - 1];
-                perm[c - i - 1] = t;
-            }
-        }
+                FLINT_SWAP(slong, perm[i], perm[c - i - 1]);
 
         for (t = 0; t < mat->r; t++)
-        {
             for (i = 0; i < k; i++)
-            {
                 gr_swap(GR_MAT_ENTRY(mat, t, i, sz), GR_MAT_ENTRY(mat, t, c - i - 1, sz), ctx);
-            }
-        }
     }
 
     return GR_SUCCESS;
