@@ -7,7 +7,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -111,7 +111,7 @@ do {                                                                \
     }                                                               \
 } while (0)
 
-static __inline__ int
+static inline int
 __mat_one(gr_ptr * M, slong * lenM, gr_ctx_t ctx)
 {
     int status = GR_SUCCESS;
