@@ -5,8 +5,8 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "gr_poly.h"
@@ -15,9 +15,12 @@ int
 gr_poly_inv(gr_poly_t res,
     const gr_poly_t poly, gr_ctx_t ctx)
 {
-    if (poly->length == 0)   /* todo: defined mod 1? */
+    if (poly->length == 0)
     {
-        return GR_DOMAIN;
+        if (gr_ctx_is_zero_ring(ctx) == T_TRUE)
+            return gr_poly_zero(res, ctx);
+        else
+            return GR_DOMAIN;
     }
     else if (poly->length == 1)
     {
