@@ -1,26 +1,21 @@
 /*
     Copyright (C) 2014 Fredrik Johansson
 
-    This file is part of Arb.
+    This file is part of FLINT.
 
-    Arb is free software: you can redistribute it and/or modify it under
+    FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "test_helpers.h"
 #include "arf.h"
 #include "mag.h"
 
-int main(void)
+TEST_FUNCTION_START(mag_rfac_ui, state)
 {
     slong iter;
-    flint_rand_t state;
-
-    flint_printf("rfac_ui....");
-    fflush(stdout);
-
-    flint_randinit(state);
 
     for (iter = 0; iter < 2000 * 0.1 * flint_test_multiplier(); iter++)
     {
@@ -60,9 +55,5 @@ int main(void)
         mag_clear(xb);
     }
 
-    flint_randclear(state);
-    flint_cleanup();
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
-
