@@ -5,12 +5,19 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "nmod.h"
+#include "fq_nmod.h"
 #include "n_poly.h"
 
+/* -O3 seems to result in worse code here. Check results for
+   nmod_mpoly_factor/profile/p-factor */
+
+#pragma GCC optimize ("-O2,-funroll-loops")
+
 /*
     conversion between polynomials in coefficient form and point-value form
     and arithmetic in point-value form
@@ -1085,4 +1092,3 @@ void n_fq_evals_fmma(
 
     TMP_END;
 }
-
