@@ -5,7 +5,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -20,8 +20,7 @@ nmod_mat_transpose(nmod_mat_t B, const nmod_mat_t A)
 
     if (B->r != A->c || B->c != A->r)
     {
-        flint_printf("Exception (nmod_mat_transpose). Incompatible dimensions.\n");
-        flint_abort();
+        flint_throw(FLINT_ERROR, "Exception (nmod_mat_transpose). Incompatible dimensions.\n");
     }
 
     if (A == B) /* In-place, guaranteed to be square */
