@@ -5,12 +5,18 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "thread_support.h"
 #include "nmod_mpoly.h"
+
+#if FLINT_KNOW_STRONG_ORDER
+
+#include "thread_pool.h"
+#include "thread_support.h"
+#include "nmod.h"
+#include "mpoly.h"
 #include "fmpz_mpoly.h"
 
 #define PROFILE_THIS 0
@@ -1710,10 +1716,6 @@ int _nmod_mpoly_divides_heap_threaded_pool(
 #endif
     TMP_INIT;
 
-#if !FLINT_KNOW_STRONG_ORDER
-    return nmod_mpoly_divides_monagan_pearce(Q, A, B, ctx);
-#endif
-
     if (B->length < 2 || A->length < 2)
     {
         return nmod_mpoly_divides_monagan_pearce(Q, A, B, ctx);
@@ -1967,3 +1969,6 @@ int nmod_mpoly_divides_heap_threaded(
 
     return divides;
 }
+#else
+typedef int this_file_is_empty;
+#endif
