@@ -5,13 +5,16 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "nmod.h"
+#include "fq_nmod.h"
+#include "n_poly.h"
+#include "mpoly.h"
 #include "nmod_mpoly.h"
 #include "nmod_mpoly_factor.h"
-#include "fq_nmod_mpoly.h"
 #include "fq_nmod_mpoly_factor.h"
 
 /*
@@ -199,7 +202,7 @@ void _nmod_mpoly_monomial_evals2_cache(
     flint_free(caches);
     flint_free(off);
 
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
     Ai = 0;
     for (i = 0; i < E->length; i++)
         Ai += E->coeffs[i].length;
@@ -528,7 +531,7 @@ int nmod_mpolyl_gcd_zippel_smprime(
     nmod_mpoly_fit_length_reset_bits(rAbar, 1, bits, ctx);
     nmod_mpoly_fit_length_reset_bits(rBbar, 1, bits, ctx);
 
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
     {
         slong * tmp_degs = FLINT_ARRAY_ALLOC(nvars, slong);
 
@@ -1236,7 +1239,7 @@ int nmod_mpolyl_gcd_zippel_lgprime(
     nmod_mpoly_fit_length_reset_bits(rAbar, 1, bits, smctx);
     nmod_mpoly_fit_length_reset_bits(rBbar, 1, bits, smctx);
 
-#ifdef FLINT_WANT_ASSERT
+#if FLINT_WANT_ASSERT
     {
         slong * tmp_degs = FLINT_ARRAY_ALLOC(nvars, slong);
 
@@ -2213,4 +2216,3 @@ int nmod_mpoly_gcd_zippel2(
 
     return _nmod_mpoly_gcd_algo(G, NULL, NULL, A, B, ctx, MPOLY_GCD_USE_ZIPPEL2);
 }
-
