@@ -5,13 +5,10 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #define NMOD_MPOLY_INLINES_C
 
-#include "flint.h"
-#include "ulong_extras.h"
 #include "nmod_mpoly.h"
-
