@@ -5,14 +5,15 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "n_poly.h"
+#include "mpoly.h"
 #include "nmod_mpoly.h"
 #include "fq_nmod_mpoly.h"
 
-
 void nmod_mpolyun_init(
     nmod_mpolyun_t A,
     flint_bitcnt_t bits,
@@ -81,13 +82,6 @@ void nmod_mpolyun_print_pretty(
     }
 }
 
-void nmod_mpolyun_swap(nmod_mpolyun_t A, nmod_mpolyun_t B)
-{
-   nmod_mpolyun_struct t = *A;
-   *A = *B;
-   *B = t;
-}
-
 void nmod_mpolyun_zero(nmod_mpolyun_t A, const nmod_mpoly_ctx_t ctx)
 {
     slong i;
@@ -1196,4 +1190,3 @@ void nmod_mpolyn_divexact_last(
 
     n_poly_clear(r);
 }
-
