@@ -5,12 +5,19 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "nmod.h"
+#include "fmpz.h"
+#include "mpoly.h"
 #include "nmod_mpoly.h"
 
+/* Currently we do not -funroll-loops by default in the nmod_mpoly module,
+   but it is worthwhile for the functions in this file. */
+#pragma GCC optimize("-funroll-loops")
+
 /* improve locality */
 #define BLOCK 128
 #define MAX_ARRAY_SIZE (WORD(300000))
@@ -59,13 +66,22 @@ void _nmod_mpoly_addmul_array1_ulong2(ulong * poly1,
       {
          for (i = ii; i < FLINT_MIN(ii + BLOCK, len2); i++)
          {
-            c2 = poly1 + 2*((slong) exp2[i]);
+            /* Hack: both the (slong) cast and writing as a shift by 1
+               instead of a multiply by 2 are needed to get GCC to
+               generate good code on Zen3. Check
+
+                   build/nmod_mpoly/profile/p-mul 1 dense 30 20
+
+               before changing this. */
+            c2 = poly1 + (((slong) exp2[i]) << 1);
 
             if (poly2[i] != 0)
             {
                for (j = jj; j < FLINT_MIN(jj + BLOCK, len3); j++)
                {
-                  c = c2 + 2*((slong) exp3[j]);
+                  /* Hack. */
+                  c = c2 + (((slong) exp3[j]) << 1);
+
                   umul_ppmm(p[1], p[0], poly2[i], poly3[j]);
                   add_ssaaaa(c[1], c[0], c[1], c[0], p[1], p[0]);
                }
@@ -105,7 +121,6 @@ void _nmod_mpoly_addmul_array1_ulong3(ulong * poly1,
    }
 }
 
-
 /****************************************************
     LEX
 ****************************************************/
