@@ -5,12 +5,19 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "test_helpers.h"
+#include "ulong_extras.h"
+#include "fmpz.h"
+#include "mpoly.h"
 #include "nmod_mpoly.h"
 
+/* Defined in t-gcd.c, t-gcd_brown.c, t-gcd_cofactors.c, t-gcd_hensel.c,
+ * t-gcd_zippel2.c and t-gcd_zippel.c */
+#define gcd_check gcd_check_gcd_cofactors
 void gcd_check(
     nmod_mpoly_t g,
     nmod_mpoly_t abar,
@@ -204,7 +211,6 @@ void gcd_check(
         flint_abort();
     }
 
-
     res = nmod_mpoly_gcd_cofactors(cg, ca, cb, abar, bbar, ctx);
     nmod_mpoly_assert_canonical(cg, ctx);
 
@@ -257,15 +263,10 @@ cleanup:
     nmod_mpoly_clear(w, ctx);
 }
 
-int
-main(void)
+TEST_FUNCTION_START(nmod_mpoly_gcd_cofactors, state)
 {
     const slong max_threads = 5;
     slong i, j, k, tmul = 3;
-    FLINT_TEST_INIT(state);
-
-    flint_printf("gcd_cofactors....");
-    fflush(stdout);
 
     {
         nmod_mpoly_ctx_t ctx;
@@ -1031,9 +1032,6 @@ main(void)
         nmod_mpoly_ctx_clear(ctx);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
-
+#undef gcd_check
