@@ -5,11 +5,13 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "fmpz.h"
 #include "fmpz_vec.h"
+#include "mpoly.h"
 #include "nmod_mpoly.h"
 
 void nmod_mpoly_univar_init(nmod_mpoly_univar_t A, const nmod_mpoly_ctx_t ctx)
@@ -121,6 +123,17 @@ void nmod_mpoly_univar_set_coeff_ui(
     return;
 }
 
+int nmod_mpoly_univar_degree_fits_si(const nmod_mpoly_univar_t A, const nmod_mpoly_ctx_t ctx)
+{
+    return A->length == 0 || fmpz_fits_si(A->exps + 0);
+}
+
+slong nmod_mpoly_univar_get_term_exp_si(nmod_mpoly_univar_t A, slong i, const nmod_mpoly_ctx_t ctx)
+{
+    FLINT_ASSERT((ulong)i < (ulong)A->length);
+    return fmpz_get_si(A->exps + i);
+}
+
 void nmod_mpoly_univar_assert_canonical(nmod_mpoly_univar_t A,
                                                     const nmod_mpoly_ctx_t ctx)
 {
@@ -577,7 +590,7 @@ static void mpoly_univar_swap_nmod_mpoly_univar(
         nmod_mpoly_swap(COEFF(A, i), B->coeffs + i, ctx);
     }
 
-    SLONG_SWAP(A->length, B->length);
+    FLINT_SWAP(slong, A->length, B->length);
 }
 
 int nmod_mpoly_univar_pseudo_gcd(
@@ -652,4 +665,3 @@ int nmod_mpoly_univar_discriminant(
 
     return success;
 }
-
