@@ -5,11 +5,14 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "nmod.h"
 #include "nmod_mat.h"
+#include "n_poly.h"
+#include "mpoly.h"
 #include "nmod_mpoly_factor.h"
 
 /* set up mock to point to the coefficients of A, which are not owned by mock */
@@ -774,7 +777,7 @@ outer_loop:
 
     for (i = 1; i < Gmarks->length; i++)
         for (j = i; j > 0 && length(perm[j-1]) > length(perm[j]); j--)
-            SLONG_SWAP(perm[j-1], perm[j]);
+            FLINT_SWAP(slong, perm[j-1], perm[j]);
 
     req_zip_images = Gmarks->length - 2;
     j = 0;
