@@ -5,7 +5,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -36,8 +36,7 @@ nmod_poly_exp_series(nmod_poly_t f, const nmod_poly_t h, slong n)
 
     if (hlen > 0 && h->coeffs[0] != UWORD(0))
     {
-        flint_printf("Exception (nmod_poly_exp_series). Constant term != 0.\n");
-        flint_abort();
+        flint_throw(FLINT_ERROR, "Exception (nmod_poly_exp_series). Constant term != 0.\n");
     }
 
     if (n <= 1 || hlen <= 1)
