@@ -6,7 +6,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -29,8 +29,7 @@ nmod_poly_invsqrt_series(nmod_poly_t res, const nmod_poly_t h, slong len)
 
     if (h->length == 0 || h->coeffs[0] == 0)
     {
-        flint_printf("Exception (nmod_poly_invsqrt_series). Division by zero.\n");
-        flint_abort();
+        flint_throw(FLINT_ERROR, "Exception (nmod_poly_invsqrt_series). Division by zero.\n");
     }
 
     if (len == 0)
