@@ -5,7 +5,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -27,8 +27,7 @@ nmod_poly_log_series(nmod_poly_t res, const nmod_poly_t f, slong n)
 
     if (flen < 1 || f->coeffs[0] != UWORD(1))
     {
-        flint_printf("Exception (nmod_poly_log_series). Constant term != 1.\n");
-        flint_abort();
+        flint_throw(FLINT_ERROR, "Exception (nmod_poly_log_series). Constant term != 1.\n");
     }
 
     if (flen == 1 || n < 2)
@@ -42,4 +41,3 @@ nmod_poly_log_series(nmod_poly_t res, const nmod_poly_t f, slong n)
     res->length = n;
 	_nmod_poly_normalise(res);
 }
-
