@@ -6,7 +6,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -27,8 +27,7 @@ void nmod_poly_make_monic(nmod_poly_t output, const nmod_poly_t input)
 {
     if (input->length == 0)
     {
-        flint_printf("Exception (nmod_poly_make_monic). Division by zero.\n");
-        flint_abort();
+        flint_throw(FLINT_ERROR, "Exception (nmod_poly_make_monic). Division by zero.\n");
     }
 
     nmod_poly_fit_length(output, input->length);
@@ -36,4 +35,3 @@ void nmod_poly_make_monic(nmod_poly_t output, const nmod_poly_t input)
                             input->coeffs, input->length, input->mod);
     output->length = input->length;
 }
-
