@@ -8,7 +8,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -38,7 +38,7 @@ nmod_poly_factor_equal_deg(nmod_poly_factor_t factors,
         flint_randclear(state);
 
         nmod_poly_init_mod(g, pol->mod);
-        nmod_poly_div(g, pol, f);
+        nmod_poly_divexact(g, pol, f);
 
         nmod_poly_factor_equal_deg(factors, f, d);
         nmod_poly_clear(f);
