@@ -5,22 +5,17 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+#include "test_helpers.h"
 #include "nmod.h"
 #include "nmod_vec.h"
 
-int
-main(void)
+TEST_FUNCTION_START(nmod_vec_reduce, state)
 {
     int i, result;
-    FLINT_TEST_INIT(state);
-
-
-    flint_printf("reduce....");
-    fflush(stdout);
 
     for (i = 0; i < 1000 * flint_test_multiplier(); i++)
     {
@@ -44,19 +39,11 @@ main(void)
 
         result = _nmod_vec_equal(vec, vec2, len);
         if (!result)
-        {
-            flint_printf("FAIL:\n");
-            flint_printf("len = %wd, n = %wd\n", len, n);
-            fflush(stdout);
-            flint_abort();
-        }
+            TEST_FUNCTION_FAIL("len = %wd, n = %wd\n", len, n);
 
         _nmod_vec_clear(vec);
         _nmod_vec_clear(vec2);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
