@@ -5,7 +5,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -15,8 +15,7 @@ void padic_get_fmpz(fmpz_t rop, const padic_t op, const padic_ctx_t ctx)
 {
     if (padic_val(op) < 0)
     {
-        flint_printf("Exception (padic_get_fmpz).  Negative valuation.\n");
-        flint_abort();
+        flint_throw(FLINT_ERROR, "Exception (padic_get_fmpz).  Negative valuation.\n");
     }
 
     if (padic_is_zero(op))
@@ -39,4 +38,3 @@ void padic_get_fmpz(fmpz_t rop, const padic_t op, const padic_ctx_t ctx)
             fmpz_clear(pow);
     }
 }
-
