@@ -5,12 +5,12 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "fmpz_vec.h"
-#include "fmpq_poly.h"
+#include "padic.h"
 #include "padic_poly.h"
 
 void padic_poly_set_fmpq_poly(padic_poly_t f,
@@ -51,4 +51,3 @@ void padic_poly_set_fmpq_poly(padic_poly_t f,
         fmpz_clear(t);
     }
 }
-
