@@ -1,18 +1,13 @@
-/*=============================================================================
-
-    This file is part of Antic.
-
-    Antic is free software: you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version. See <http://www.gnu.org/licenses/>.
-
-=============================================================================*/
-/******************************************************************************
-
+/*
     Copyright (C) 2012 William Hart
 
-******************************************************************************/
+    This file is part of FLINT.
+
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
+*/
 
 #include <stdlib.h>
 #include "flint.h"
@@ -22,7 +17,6 @@
 
 int main(int argc, char *argv[])
 {
-    int result;
     slong exp, val, num, B1, B2, i;
 
     if (argc != 6)
@@ -42,7 +36,6 @@ int main(int argc, char *argv[])
     for (i = 0; i < num; i++)
     {
         fmpz_t D, exponent;
-        slong e;
 
         fmpz_init(D);
         fmpz_init(exponent);
