@@ -5,23 +5,18 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
 #include "ulong_extras.h"
+#include "test_helpers.h"
 
-int main(void)
+TEST_FUNCTION_START(flint_ctz, state)
 {
    int i, result;
-   FLINT_TEST_INIT(state);
 
-
-   flint_printf("flint_ctz....");
-   fflush(stdout);
-
-   for (i = 0; i < 1000000; i++)
+   for (i = 0; i < 100000 * flint_test_multiplier(); i++)
    {
       mp_limb_t n;
       unsigned int count = 0;
@@ -33,16 +28,8 @@ int main(void)
 
       result = ((n == UWORD(0)) || (((n >> count) & UWORD(1)) && (l_shift(n, FLINT_BITS-count) == UWORD(0))));
       if (!result)
-      {
-         flint_printf("FAIL:\n");
-         flint_printf("n = %wu, count = %u\n", n, count);
-         fflush(stdout);
-         flint_abort();
-      }
+            TEST_FUNCTION_FAIL("n = %wu, count = %u\n", n, count);
    }
 
-   FLINT_TEST_CLEANUP(state);
-
-   flint_printf("PASS\n");
-   return 0;
+   TEST_FUNCTION_END(state);
 }
