@@ -5,7 +5,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -14,6 +14,10 @@
 
 #include "thread_pool.h"
 
+#if FLINT_USES_PTHREAD && defined(HAVE_PTHREAD_NP_H)
+# include <pthread_np.h>
+#endif
+
 /*
     cpus[0] is cpu number for main thread
     cpus[1], ..., cpus[length - 1] are cpu numbers for elements of pool
