@@ -7,11 +7,10 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
 #include "ulong_extras.h"
 
 int
@@ -21,11 +20,10 @@ n_is_strong_probabprime2_preinv(mp_limb_t n, mp_limb_t ninv, mp_limb_t a,
     mp_limb_t t = d;
     mp_limb_t y;
 
-    /* Map large base to range 2 ... n - 1 */
-    if (a >= n)
-       a = n_mod2_preinv(a, n, ninv);
+    FLINT_ASSERT(a < n);
 
-    if ((a <= 1) || (a == n - 1))  return 1;
+    if (a <= 1 || a == n - 1)
+        return 1;
 
     y = n_powmod2_ui_preinv(a, t, n, ninv);
 
