@@ -5,22 +5,16 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
+#include "test_helpers.h"
 #include "ulong_extras.h"
 
-int main(void)
+TEST_FUNCTION_START(n_clog, state)
 {
     int i, result;
-    FLINT_TEST_INIT(state);
-
-    flint_printf("clog....");
-    fflush(stdout);
-
-
 
     for (i = 0; i < 10000 * flint_test_multiplier(); i++)
     {
@@ -36,17 +30,13 @@ int main(void)
 
         result = (x < a && ((k > 0) ? ((a + b - 1) / b <= x) : (a <= 1)));
         if (!result)
-        {
-            flint_printf("FAIL:\n");
-            flint_printf("a = %wu\n", a);
-            flint_printf("b = %wu\n", b);
-            flint_printf("x = %wu\n", x);
-            flint_printf("k = %wu\n", k);
-        }
+            TEST_FUNCTION_FAIL(
+                    "a = %wu\n"
+                    "b = %wu\n"
+                    "x = %wu\n"
+                    "k = %wu\n",
+                    a, b, x, k);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
