@@ -5,24 +5,17 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
+#include "test_helpers.h"
 #include "ulong_extras.h"
 
-int main(void)
+TEST_FUNCTION_START(n_primes, state)
 {
     slong n;
 
-    FLINT_TEST_INIT(state);
-
-    flint_printf("primes....");
-    fflush(stdout);
-
-    _flint_rand_init_gmp(state);
-
     /* compare with n_nextprime */
     {
         n_primes_t iter;
@@ -37,12 +30,7 @@ int main(void)
             q = n_nextprime(q, 0);
 
             if (p != q)
-            {
-                flint_printf("FAIL\n");
-                flint_printf("i = %wu, p = %wu, q = %wu\n", i, p, q);
-                fflush(stdout);
-                flint_abort();
-            }
+                TEST_FUNCTION_FAIL("i = %wu, p = %wu, q = %wu\n", i, p, q);
         }
 
         n_primes_clear(iter);
@@ -66,18 +54,10 @@ int main(void)
             s++;
 
         if (s != primepi[n])
-        {
-            flint_printf("FAIL\n");
-            flint_printf("pi(10^%wd) = %u, computed = %wu\n", n, primepi[n], s);
-            fflush(stdout);
-            flint_abort();
-        }
+            TEST_FUNCTION_FAIL("pi(10^%wd) = %u, computed = %wu\n", n, primepi[n], s);
 
         n_primes_clear(iter);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
