@@ -5,22 +5,17 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
+#include "test_helpers.h"
 #include "ulong_extras.h"
 
-int main(void)
+TEST_FUNCTION_START(n_primes_jump_after, state)
 {
     slong j, k, l;
 
-    FLINT_TEST_INIT(state);
-
-    flint_printf("primes_jump_after....");
-    fflush(stdout);
-
     for (j = 0; j < 10; j++)
     {
         n_primes_t iter;
@@ -41,20 +36,12 @@ int main(void)
                 q = n_nextprime(q, 0);
 
                 if (p != q)
-                {
-                    flint_printf("FAIL\n");
-                    flint_printf("p = %wu, q = %wu\n", p, q);
-                    fflush(stdout);
-                    flint_abort();
-                }
+                    TEST_FUNCTION_FAIL("p = %wu, q = %wu\n", p, q);
             }
         }
 
         n_primes_clear(iter);
     }
 
-    FLINT_TEST_CLEANUP(state);
-
-    flint_printf("PASS\n");
-    return 0;
+    TEST_FUNCTION_END(state);
 }
