@@ -5,20 +5,16 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
-#include "flint.h"
+#include "test_helpers.h"
 #include "ulong_extras.h"
 
-int main(void)
+TEST_FUNCTION_START(n_primitive_root_prime, state)
 {
     int i, j;
-    FLINT_TEST_INIT(state);
-
-    flint_printf("primitive_root_prime....");
-    fflush(stdout);
 
     for (i = 0; i < 100; i++)
     {
@@ -36,17 +32,9 @@ int main(void)
         for (j = 0; j < factors.num; j++)
         {
             if (n_powmod_precomp(root, (p-1) / factors.p[j], p, pinv) == 1)
-            {
-                flint_printf("FAIL:\n");
-                flint_printf("%wu ** (%wu / %wu) == 1 mod %wu\n", root, p-1, factors.p[j], p);
-                fflush(stdout);
-                flint_abort();
-            }
+                TEST_FUNCTION_FAIL("%wu ** (%wu / %wu) == 1 mod %wu\n", root, p-1, factors.p[j], p);
         }
     }
 
-   FLINT_TEST_CLEANUP(state);
-   flint_printf("PASS\n");
-   return 0;
-
+    TEST_FUNCTION_END(state);
 }
